#ifndef _HC_NET_SDK_H_
#define _HC_NET_SDK_H_

#define NET_DVR_API  extern "C"__declspec(dllimport)

//Macro definition
#define MAX_NAMELEN			    16		//DVR's local Username
#define MAX_RIGHT			    32		//Authority permitted by Device(1-12 for local authority, 13-32 for remote authority)
#define NAME_LEN			    32      //Username length
#define PASSWD_LEN			    16      //Password length
#define SERIALNO_LEN		    48      //SN length
#define MACADDR_LEN			    6       //Length of MAC address
#define MAX_ETHERNET		    2       //Configurable Ethernet of device
#define PATHNAME_LEN		    128     //length of path name

#define MAX_TIMESEGMENT_V30	    8       //Maximum number of time segments in 9000 DVR's guard schedule
#define MAX_TIMESEGMENT		    4       //Maximum number of time segments in 8000 DVR's guard schedule
#define MAX_SHELTERNUM			4       //Maximum number of mask areas in 8000 DVR
#define MAX_DAYS				7       //The number of days in a week
#define PHONENUMBER_LEN			32      //Maximum length of PPPOE number

#define MAX_DISKNUM_V30			33		//Maximum disk number in 9000 DVR, including 16 internal SATA disks, 1 eSTAT disk and 16 NFS disks
#define MAX_DISKNUM		        16      //Maximum disk number in 8000 DVR
#define MAX_DISKNUM_V10		    8       //used in 1.2 or earlier version

#define MAX_WINDOW_V30			32      //9000 maximum number of local display windows
#define MAX_WINDOW				16      //8000 maximum number of local display windows
#define MAX_VGA_V30				4       //9000 maximum number of VGA
#define MAX_VGA			    	1       //8000 maximum number of VGA

#define MAX_USERNUM_V30			32      //Maximum number of 9000 DVR users
#define MAX_USERNUM			    16      //Maximum number of 8000 DVR users
#define MAX_EXCEPTIONNUM_V30	32      //Maximum number of exceptions handled by 9000 DVR
#define MAX_EXCEPTIONNUM		16      //Maximum number of exceptions handled by 8000 DVR
#define MAX_LINK				6       //Maximum number of video connections to 8000's single channel

#define MAX_DECPOOLNUM			4       //Maximum loop decoding number supported by each decoding channel of single channel decoder
#define MAX_DECNUM				4       //Maximum decoding channel number of single channel decoder(only has one channel, others are reserved)
#define MAX_TRANSPARENTNUM		2       //Maximum number of Transparent channel in single channel decoder
#define MAX_CYCLE_CHAN			16      //Maximum number of loop channels in single channel decoder
#define MAX_DIRNAME_LENGTH		80      //Maximum directory length

#define MAX_STRINGNUM_V30		8		//Maximum number of OSD lines in 9000 DVR
#define MAX_STRINGNUM			4       //Maximum number of OSD lines in 8000 DVR
#define MAX_STRINGNUM_EX		8       //8000 customized extensions
#define MAX_AUXOUT_V30			16      //9000 maximum number of AUX output ports
#define MAX_AUXOUT			    4       //8000 maximum number of AUX output ports
#define MAX_HD_GROUP			16      //9000 maximum number of hard disk groups
#define MAX_NFS_DISK			8       //8000 maximum number of NFS disks

#define IW_ESSID_MAX_SIZE	    32      //SSID length of WIFI
#define IW_ENCODING_TOKEN_MAX	32      //Maximum bytes of WIFI security Key
#define MAX_SERIAL_NUM			64	    //Maximum number of Transparent channel
#define MAX_DDNS_NUMS	        10      //Maximum number of DDNS in 9000
#define MAX_DOMAIN_NAME		    64		//Maximum Domain Name length
#define MAX_EMAIL_ADDR_LEN		48		//Maximum Email Address length
#define MAX_EMAIL_PWD_LEN	    32      //Maximun Email password length

#define MAXPROGRESS		        100     //Maximum percent while playing back
#define MAX_SERIALNUM	        2       //Serial Port supported by 8000 DVR, 1-232, 2-485
#define CARDNUM_LEN		        20      //Card number length
#define MAX_VIDEOOUT_V30        4       //9000 DVR analog video output number. 
#define MAX_VIDEOOUT	        2       //8000 DVR analog video output number

#define MAX_PRESET_V30			    256		/* 9000 Preset number of PTZ  */
#define MAX_TRACK_V30			    256		/* 9000 Track number of PTZ   */
#define MAX_CRUISE_V30			    256		/* 9000 Cruise number of PTZ  */
#define MAX_PRESET				    128		/* 8000 Preset number of PTZ  */
#define MAX_TRACK				    128		/* 8000 Track number of PTZ   */
#define MAX_CRUISE				    128		/* 8000 Cruise number of PTZ  */

#define CRUISE_MAX_PRESET_NUMS	    32 	    /* Maximum number of Cruise points in one Cruise */

#define MAX_SERIAL_PORT             8       // Maximum number of RS232 supported by 9000 DVR
#define MAX_PREVIEW_MODE            8       /* Maximum number of display layout mode; single windows/4 windows/9 windows/16 windows/... */
#define MAX_MATRIXOUT               16      /* Maximum number of analog matrix output */
#define LOG_INFO_LEN                11840   /* Additional information of Log */
#define DESC_LEN                    16      /* String length of PTZ description */
#define PTZ_PROTOCOL_NUM            200     /* Maximum number of PTZ protocols in 9000 DVR */

#define MAX_AUDIO			        1       //Number of talk channels in 8000 DVR
#define MAX_AUDIO_V30			    2       //Number of talk channels in 9000 DVR
#define MAX_CHANNUM			        16      //Maximum number of video/audio channels in 8000 DVR
#define MAX_ALARMIN			        16      //Maximum number of alarm input channels in 8000 DVR
#define MAX_ALARMOUT		        4       //Maximum number of alarm output channels in 8000 DVR
//9000 IP Camera
#define MAX_ANALOG_CHANNUM          32      //32 analog channels in total
#define MAX_ANALOG_ALARMOUT         32      //32 analog alarm output channels intotal
#define MAX_ANALOG_ALARMIN          32      //32 analog alarm input channels intotal
#define MAX_IP_DEVICE               32      //9000 DVR can connect 32 IP devices
#define MAX_IP_CHANNEL              32      //9000 DVR can connect 32 IP channels
#define MAX_IP_ALARMIN              128     //Maximum number of alarm input channels that can be added
#define MAX_IP_ALARMOUT             64      //Maximum number of alarm output channels that can be added

/*Maximum channels number including analog channels and IP channels */
#define MAX_CHANNUM_V30               ( MAX_ANALOG_CHANNUM + MAX_IP_CHANNEL )//64
#define MAX_ALARMOUT_V30              ( MAX_ANALOG_ALARMOUT + MAX_IP_ALARMOUT )//96
#define MAX_ALARMIN_V30               ( MAX_ANALOG_ALARMIN + MAX_IP_ALARMIN )//160

/*******************Global Error Code**********************/	
#define NET_DVR_FAIL 						-1
#define NET_DVR_NOERROR 					0	//No Error
#define NET_DVR_PASSWORD_ERROR 				1	//Username or Password error
#define NET_DVR_NOENOUGHPRI 				2	//Don't have enough authority 
#define NET_DVR_NOINIT 						3	//have not Initialized
#define NET_DVR_CHANNEL_ERROR 				4	//Channel number error
#define NET_DVR_OVER_MAXLINK 				5	//Number of clients connecting to DVR beyonds the Maximum
#define NET_DVR_VERSIONNOMATCH				6	//Version is not matched
#define NET_DVR_NETWORK_FAIL_CONNECT		7	//Connect to server failed
#define NET_DVR_NETWORK_SEND_ERROR			8	//Send data to server failed
#define NET_DVR_NETWORK_RECV_ERROR			9	//Receive data from server failed
#define NET_DVR_NETWORK_RECV_TIMEOUT		10	//Receive data from server timeout
#define NET_DVR_NETWORK_ERRORDATA			11	//Transfered data has error
#define NET_DVR_ORDER_ERROR					12	//Wrong Sequence of invoking API
#define NET_DVR_OPERNOPERMIT				13	//No such authority. 
#define NET_DVR_COMMANDTIMEOUT				14	//Execute command timeout
#define NET_DVR_ERRORSERIALPORT				15	//Serial port number error
#define NET_DVR_ERRORALARMPORT				16	//Alarm port error
#define NET_DVR_PARAMETER_ERROR 			17  //Parameters error
#define NET_DVR_CHAN_EXCEPTION				18	//Server channel in error status
#define NET_DVR_NODISK						19	//No hard disk
#define NET_DVR_ERRORDISKNUM				20	//Hard disk number error
#define NET_DVR_DISK_FULL					21	//Server's hard disk is full
#define NET_DVR_DISK_ERROR					22	//Server's hard disk error
#define NET_DVR_NOSUPPORT					23	//Server doesn't support
#define NET_DVR_BUSY						24	//Server is busy
#define NET_DVR_MODIFY_FAIL					25	//Server modification failed
#define NET_DVR_PASSWORD_FORMAT_ERROR		26	//Input format of Password error
#define NET_DVR_DISK_FORMATING				27	//Hard disk is formating, cannot execute.  
#define NET_DVR_DVRNORESOURCE				28	//DVR don't have enough resource
#define	NET_DVR_DVROPRATEFAILED				29  //DVR Operation failed
#define NET_DVR_OPENHOSTSOUND_FAIL 			30  //Open PC audio failed
#define NET_DVR_DVRVOICEOPENED 				31  //Server's talk channel is occupied 
#define	NET_DVR_TIMEINPUTERROR				32  //Time input is not correct
#define	NET_DVR_NOSPECFILE					33  //Can't playback the file that does not exist in Server
#define NET_DVR_CREATEFILE_ERROR			34	//Create file error
#define	NET_DVR_FILEOPENFAIL				35  //Open file error
#define	NET_DVR_OPERNOTFINISH				36  //The previous operation is not finished yet
#define	NET_DVR_GETPLAYTIMEFAIL				37  //Get current playing time error
#define	NET_DVR_PLAYFAIL					38  //Playback error
#define NET_DVR_FILEFORMAT_ERROR			39  //Wrong file format
#define NET_DVR_DIR_ERROR					40	//Wrong directory 
#define NET_DVR_ALLOC_RESOURCE_ERROR		41  //Assign resource error
#define NET_DVR_AUDIO_MODE_ERROR			42	//Audio card mode error
#define NET_DVR_NOENOUGH_BUF				43	//Buffer is too small
#define NET_DVR_CREATESOCKET_ERROR		 	44	//Create SOCKET error
#define NET_DVR_SETSOCKET_ERROR				45	//Setup SOCKET error
#define NET_DVR_MAX_NUM						46	//Reach the maximum number
#define NET_DVR_USERNOTEXIST				47	//User does not exist
#define NET_DVR_WRITEFLASHERROR				48  //Write to FLASH error
#define NET_DVR_UPGRADEFAIL					49  //DVR update failed 
#define NET_DVR_CARDHAVEINIT				50  //Decoding Card has been initialized already
#define NET_DVR_PLAYERFAILED				51	//Invoke API of PlayCtrl.dll error
#define NET_DVR_MAX_USERNUM					52  //Reach the maximum number of DVR Users
#define NET_DVR_GETLOCALIPANDMACFAIL		53  //Failed to get Client software's IP or MAC address
#define NET_DVR_NOENCODEING					54	//No encoding on this channel
#define NET_DVR_IPMISMATCH					55	//IP address is not matched
#define NET_DVR_MACMISMATCH					56	//MAC address is not matched
#define NET_DVR_UPGRADELANGMISMATCH			57	//Update file has wrong language
#define NET_DVR_MAX_PLAYERPORT				58	//Reach the maximum player number
#define NET_DVR_NOSPACEBACKUP				59	//There is no enough space on the backup device
#define NET_DVR_NODEVICEBACKUP				60	//Failed to find the specified backup device 
#define NET_DVR_PICTURE_BITS_ERROR			61	//Image has wrong color bit, 24 color only
#define NET_DVR_PICTURE_DIMENSION_ERROR		62	//Image size exceeds the maximum value; smaller than 128*256
#define NET_DVR_PICTURE_SIZ_ERROR			63	//Image file exceeds the maximum size; smaller than 100K
#define NET_DVR_LOADPLAYERSDKFAILED			64	//Failed to load the player SDK from current directory
#define NET_DVR_LOADPLAYERSDKPROC_ERROR		65	//Failed to find the API's entry in player SDK
#define NET_DVR_LOADDSSDKFAILED				66	//Failed to load the DSsdk from current directory
#define NET_DVR_LOADDSSDKPROC_ERROR		    67	//Failed to find the API's entry in DSsDK
#define NET_DVR_DSSDK_ERROR					68	//Failed to invole the API of DSsDK.dll
#define NET_DVR_VOICEMONOPOLIZE				69	//Audio card has been occupied exclusively
#define NET_DVR_JOINMULTICASTFAILED			70	//Join to multicast group error
#define NET_DVR_CREATEDIR_ERROR				71	//Failed to create log directory
#define NET_DVR_BINDSOCKET_ERROR			72	//Failed to bind socked error. 
#define NET_DVR_SOCKETCLOSE_ERROR			73	//socket is disconnected, that caused by network disconnected or unreachable destination mostly
#define NET_DVR_USERID_ISUSING			    74	//User ID is using when logout
#define NET_DVR_SOCKETLISTEN_ERROR			75	//Socket listen error
#define NET_DVR_PROGRAM_EXCEPTION			76	//Application error
#define NET_DVR_WRITEFILE_FAILED			77	//Failed to write file
#define NET_DVR_FORMAT_READONLY				78  //Forbidden to format read only disk
#define NET_DVR_WITHSAMEUSERNAME		    79  //Same user name already exists.
#define NET_DVR_DEVICETYPE_ERROR            80  /*Device Model is not matched when import parameters*/
#define NET_DVR_LANGUAGE_ERROR              81  /*Audio is not matched when import parameters*/
#define NET_DVR_PARAVERSION_ERROR           82  /*Software version is not matched when import parameters*/
#define NET_DVR_IPCHAN_NOTALIVE             83  /*IP Channels is off line when */
#define NET_DVR_RTSP_SDK_ERROR				84	/*Failed to load IPC communication library, StreamTransClient.dll*/
#define NET_DVR_CONVERT_SDK_ERROR			85	/*Failed to load format convertion library CVT_StdToHik.dll*/
#define NET_DVR_IPC_COUNT_OVERFLOW			86  /*ip count overflow*/

#define  NET_PLAYM4_NOERROR					    500	//no error
#define	 NET_PLAYM4_PARA_OVER				    501	//input parameter is invalid;
#define  NET_PLAYM4_ORDER_ERROR				    502	//The order of the function to be called is error.
#define	 NET_PLAYM4_TIMER_ERROR				    503	//Create multimedia clock failed;
#define  NET_PLAYM4_DEC_VIDEO_ERROR			    504	//Decode video data failed.
#define  NET_PLAYM4_DEC_AUDIO_ERROR			    505	//Decode audio data failed.
#define	 NET_PLAYM4_ALLOC_MEMORY_ERROR		    506	//Allocate memory failed.
#define  NET_PLAYM4_OPEN_FILE_ERROR			    507	//Open the file failed.
#define  NET_PLAYM4_CREATE_OBJ_ERROR		    508	//Create thread or event failed
#define  NET_PLAYM4_CREATE_DDRAW_ERROR		    509	//Create DirectDraw object failed.
#define  NET_PLAYM4_CREATE_OFFSCREEN_ERROR      510	//failed when creating off-screen surface.
#define  NET_PLAYM4_BUF_OVER			        511	//buffer is overflow
#define  NET_PLAYM4_CREATE_SOUND_ERROR	        512	//failed when creating audio device.	
#define	 NET_PLAYM4_SET_VOLUME_ERROR	        513	//Set volume failed
#define  NET_PLAYM4_SUPPORT_FILE_ONLY	        514	//The function only support play file.
#define  NET_PLAYM4_SUPPORT_STREAM_ONLY	        515	//The function only support play stream.
#define  NET_PLAYM4_SYS_NOT_SUPPORT		        516	//System not support.
#define  NET_PLAYM4_FILEHEADER_UNKNOWN          517	//No file header.
#define  NET_PLAYM4_VERSION_INCORRECT	        518	//The version of decoder and encoder is not adapted.  
#define  NET_PALYM4_INIT_DECODER_ERROR          519	//Initialize decoder failed.
#define  NET_PLAYM4_CHECK_FILE_ERROR	        520	//The file data is unknown.
#define  NET_PLAYM4_INIT_TIMER_ERROR	        521	//Initialize multimedia clock failed.
#define	 NET_PLAYM4_BLT_ERROR			        522	//Blt failed.
#define  NET_PLAYM4_UPDATE_ERROR		        523	//Update failed.
#define  NET_PLAYM4_OPEN_FILE_ERROR_MULTI       524 //openfile error, streamtype is multi
#define  NET_PLAYM4_OPEN_FILE_ERROR_VIDEO       525 //openfile error, streamtype is video
#define  NET_PLAYM4_JPEG_COMPRESS_ERROR         526 //JPEG compress error
#define  NET_PLAYM4_EXTRACT_NOT_SUPPORT         527	//Don't support the version of this file.
#define  NET_PLAYM4_EXTRACT_DATA_ERROR          528	//extract video data failed.

/*******************Global Error Code end**********************/

/*************************************************
Return value of NET_DVR_IsSupport(), 
the definition of bit 1 to bit 9 is below and TRUE means support
**************************************************/
#define NET_DVR_SUPPORT_DDRAW			0x01//Support DIRECTDRAW, otherwise Player can't work
#define NET_DVR_SUPPORT_BLT				0x02//Display adapter supports BLT, otherwise Player can't work
#define NET_DVR_SUPPORT_BLTFOURCC		0x04//BLT supports color conversion, otherwise, Player will do RGB conversion in software mode
#define NET_DVR_SUPPORT_BLTSHRINKX		0x08//BLT supports X-coordinate shrink, otherwise, Player will do it in software mode
#define NET_DVR_SUPPORT_BLTSHRINKY		0x10//BLT supports Y-coordinate shrink, otherwise, Player will do it in software mode
#define NET_DVR_SUPPORT_BLTSTRETCHX		0x20//BLT supports X-coordinate expand, otherwise, Player will do it in software mode
#define NET_DVR_SUPPORT_BLTSTRETCHY		0x40//BLT supports Y-coordinate expand, otherwise, Player will do it in software mode
#define NET_DVR_SUPPORT_SSE				0x80//CPU supports SSE commandsIntel Pentium3 or higher version supports SSE
#define NET_DVR_SUPPORT_MMX				0x100//CPU supports MMX commandsIntel Pentium3 or higher version supports MMX

/**********************PTZ Commands begin*************************/	
#define LIGHT_PWRON		2	/* Switch on light */
#define WIPER_PWRON		3	/* Switch on Wiper */
#define FAN_PWRON		4	/* Switch on Fan */
#define HEATER_PWRON	5	/* Switch on Heater */
#define AUX_PWRON1		6	/* Switch on auxiliary equipment 1*/
#define AUX_PWRON2		7	/* Switch on auxiliary equipment 2*/
#define SET_PRESET		8	/* Configure Preset */
#define CLE_PRESET		9	/* Clean Preset */

#define ZOOM_IN			11	/* Zoom in*/
#define ZOOM_OUT		12	/* Zoom out */
#define FOCUS_NEAR      13  /* Focus in */
#define FOCUS_FAR       14  /* Focus out*/
#define IRIS_OPEN       15  /* Iris open */
#define IRIS_CLOSE      16  /* Iris close */

#define TILT_UP			21	/* PTZ tilt up */
#define TILT_DOWN		22	/* PTZ tilt down*/
#define PAN_LEFT		23	/* PTZ pan left */
#define PAN_RIGHT		24	/* PTZ pan right*/
#define UP_LEFT			25	/* PTZ turn up and left */
#define UP_RIGHT		26	/* PTZ turn up and right */
#define DOWN_LEFT		27	/* PTZ turn down and left */
#define DOWN_RIGHT		28	/* PTZ turn down and right */
#define PAN_AUTO		29	/* PTZ auto pan */

#define FILL_PRE_SEQ	30	/* Add preset to sequence */
#define SET_SEQ_DWELL	31	/* Set cruise point's residence time */
#define SET_SEQ_SPEED	32	/* Set cruise point */
#define CLE_PRE_SEQ		33	/* Delete preset from sequence */
#define STA_MEM_CRUISE	34	/* Start recording trace */
#define STO_MEM_CRUISE	35	/* Stop recoding trace  */
#define RUN_CRUISE		36	/* Start Cruise */
#define RUN_SEQ			37	/* Start Sequence */
#define STOP_SEQ		38	/* Stop Sequence */
#define GOTO_PRESET		39	/* Go to preset */

/**********************PTZ Commands end*************************/	

/*************************************************
Play Control Commands
Macro Definition
NET_DVR_PlayBackControl
NET_DVR_PlayControlLocDisplay
NET_DVR_DecPlayBackCtrl
**************************************************/	
#define NET_DVR_PLAYSTART		1//Start Play
#define NET_DVR_PLAYSTOP		2//Stop Play
#define NET_DVR_PLAYPAUSE		3//Pause Play
#define NET_DVR_PLAYRESTART		4//Restore Play
#define NET_DVR_PLAYFAST		5//Play faster
#define NET_DVR_PLAYSLOW		6//Play slower
#define NET_DVR_PLAYNORMAL		7//Normal Speed
#define NET_DVR_PLAYFRAME		8//Play frame by frame
#define NET_DVR_PLAYSTARTAUDIO	9//Open audio
#define NET_DVR_PLAYSTOPAUDIO	10//Close audio
#define NET_DVR_PLAYAUDIOVOLUME	11//Adjust volume 
#define NET_DVR_PLAYSETPOS		12//change the playback progress 
#define NET_DVR_PLAYGETPOS		13//Get the playback progress
#define NET_DVR_PLAYGETTIME		14//Get the played time(available when playback by time)
#define NET_DVR_PLAYGETFRAME	15//Get the played frame number(available when playback by file)
#define NET_DVR_GETTOTALFRAMES  16//Get total frame number of current file(available when playback by file)
#define NET_DVR_GETTOTALTIME    17//Get total time of current file(available when playback by file)
#define NET_DVR_THROWBFRAME		20//Discard B frame
#define NET_DVR_SETSPEED		24//Setup stream speed
#define NET_DVR_KEEPALIVE		25//Keep connection with server(if callback is blocked, send it every 2 second)

//Remote Key//
/* key value send to CONFIG program */
#define KEY_CODE_1 1
#define KEY_CODE_2 2
#define KEY_CODE_3 3
#define KEY_CODE_4 4
#define KEY_CODE_5 5
#define KEY_CODE_6 6
#define KEY_CODE_7 7
#define KEY_CODE_8 8
#define KEY_CODE_9 9
#define KEY_CODE_0 10
#define KEY_CODE_POWER 11
#define KEY_CODE_MENU 12
#define KEY_CODE_ENTER 13
#define KEY_CODE_CANCEL 14
#define KEY_CODE_UP 15
#define KEY_CODE_DOWN 16
#define KEY_CODE_LEFT 17
#define KEY_CODE_RIGHT 18
#define KEY_CODE_EDIT 19
#define KEY_CODE_ADD 20
#define KEY_CODE_MINUS 21
#define KEY_CODE_PLAY 22
#define KEY_CODE_REC 23
#define KEY_CODE_PAN 24
#define KEY_CODE_M 25
#define KEY_CODE_A 26
#define KEY_CODE_F1 27
#define KEY_CODE_F2 28

/* for PTZ control */
#define KEY_PTZ_UP_START KEY_CODE_UP
#define KEY_PTZ_UP_STOP 32

#define KEY_PTZ_DOWN_START KEY_CODE_DOWN
#define KEY_PTZ_DOWN_STOP 33

#define KEY_PTZ_LEFT_START KEY_CODE_LEFT
#define KEY_PTZ_LEFT_STOP 34

#define KEY_PTZ_RIGHT_START KEY_CODE_RIGHT
#define KEY_PTZ_RIGHT_STOP 35

#define KEY_PTZ_AP1_START KEY_CODE_EDIT /* Iris+ */
#define KEY_PTZ_AP1_STOP 36

#define KEY_PTZ_AP2_START KEY_CODE_PAN /* Iris- */
#define KEY_PTZ_AP2_STOP 37

#define KEY_PTZ_FOCUS1_START KEY_CODE_A /* Focus+ */
#define KEY_PTZ_FOCUS1_STOP 38

#define KEY_PTZ_FOCUS2_START KEY_CODE_M /* Focus- */
#define KEY_PTZ_FOCUS2_STOP 39

#define KEY_PTZ_B1_START 40 /* Zoom+ */
#define KEY_PTZ_B1_STOP 41

#define KEY_PTZ_B2_START 42 /* Zoom- */
#define KEY_PTZ_B2_STOP 43

//New in 9000
#define KEY_CODE_11 44
#define KEY_CODE_12 45
#define KEY_CODE_13 46
#define KEY_CODE_14 47
#define KEY_CODE_15 48
#define KEY_CODE_16 49

/*************************Parameter Configure Commands begin*******************************/
//Used for NET_DVR_SetDVRConfig and NET_DVR_GetDVRConfig, pay attention to corresponding Structure

#define NET_DVR_GET_DEVICECFG		100		//Get DVR Parameters
#define NET_DVR_SET_DEVICECFG		101		//Set DVR Parameters
#define NET_DVR_GET_NETCFG			102		//Get Network Parameters
#define NET_DVR_SET_NETCFG			103		//Set Network Parameters
#define NET_DVR_GET_PICCFG			104		//Get Image Parameters
#define NET_DVR_SET_PICCFG			105		//Set Image Parameters
#define NET_DVR_GET_COMPRESSCFG		106		//Get Compression Parameters
#define NET_DVR_SET_COMPRESSCFG		107		//Set Compression Parameters
#define NET_DVR_GET_RECORDCFG		108		//Get Record Parameters
#define NET_DVR_SET_RECORDCFG		109		//Set Record Parameters
#define NET_DVR_GET_DECODERCFG		110		//Get PTZ Parameters
#define NET_DVR_SET_DECODERCFG		111		//Set PTZ Parameters
#define NET_DVR_GET_RS232CFG 		112		//Get RS232 Parameters
#define NET_DVR_SET_RS232CFG		113		//Set RS232 Parameters
#define NET_DVR_GET_ALARMINCFG 		114		//Get Alarm In Parameters
#define NET_DVR_SET_ALARMINCFG		115		//Set Alarm In Parameters
#define NET_DVR_GET_ALARMOUTCFG 	116		//Get Alarm Out Parameters
#define NET_DVR_SET_ALARMOUTCFG		117		//Set Alarm Out Parameters
#define NET_DVR_GET_TIMECFG 		118		//Get DVR time
#define NET_DVR_SET_TIMECFG			119		//Set DVR time
#define NET_DVR_GET_PREVIEWCFG 		120		//Get Local Preview Parameters
#define NET_DVR_SET_PREVIEWCFG		121		//Set Local Preview Parameters
#define NET_DVR_GET_VIDEOOUTCFG 	122		//Get Video Output Parameters
#define NET_DVR_SET_VIDEOOUTCFG		123		//Set Video Output Parameters
#define NET_DVR_GET_USERCFG 		124		//Get User Parameters
#define NET_DVR_SET_USERCFG			125		//Set User Parameters
#define NET_DVR_GET_EXCEPTIONCFG 	126		//Get Exception Parameters
#define NET_DVR_SET_EXCEPTIONCFG	127		//Set Exception Parameters
#define NET_DVR_GET_ZONEANDDST		128		//Get Time Zone & DST Parameters
#define NET_DVR_SET_ZONEANDDST		129		//Set Time Zone & DST Parameters
#define NET_DVR_GET_SHOWSTRING		130		//Get OSD Parameters
#define NET_DVR_SET_SHOWSTRING		131		//Set OSD Parameters
#define NET_DVR_GET_EVENTCOMPCFG	132		//Get Event Record Parameters
#define NET_DVR_SET_EVENTCOMPCFG	133		//Set Event Record  Parameters

#define NET_DVR_GET_AUXOUTCFG		140		//Get External Alarm Configuration
#define NET_DVR_SET_AUXOUTCFG		141		//Set External Alarm Configuration
#define NET_DVR_GET_PREVIEWCFG_AUX 	142		//Get -S device dual output parameters
#define NET_DVR_SET_PREVIEWCFG_AUX	143		//Set -S device dual output parameters

#define NET_DVR_GET_PICCFG_EX		200		//Get Image Parameters (Extended)
#define NET_DVR_SET_PICCFG_EX		201		//Set Image Parameters (Extended)
#define NET_DVR_GET_USERCFG_EX 		202		//Get User Parameters(Extended)
#define NET_DVR_SET_USERCFG_EX		203		//Set User Parameters(Extended)
#define NET_DVR_GET_COMPRESSCFG_EX	204		//Get Compression Parameters (Extended)
#define NET_DVR_SET_COMPRESSCFG_EX	205		//Set Compression Parameters (Extended)


#define NET_DVR_GET_NETAPPCFG		222		//Get Network Application Parameters NTP/DDNS/EMAIL
#define NET_DVR_SET_NETAPPCFG		223		//Set Network Application Parameters NTP/DDNS/EMAIL
#define NET_DVR_GET_NTPCFG			224		//Get Network Application Parameters NTP
#define NET_DVR_SET_NTPCFG			225		//Set Network Application Parameters NTP
#define NET_DVR_GET_DDNSCFG			226		//Get Network Application Parameters DDNS
#define NET_DVR_SET_DDNSCFG			227		//Set Network Application Parameters DDNS

//Corresponding with NET_DVR_EMAILPARA
#define NET_DVR_GET_EMAILCFG		228		//Get EMAIL Configuration
#define NET_DVR_SET_EMAILCFG		229		//Set EMAIL Configuration

#define NET_DVR_GET_NFSCFG			230		/* NFS disk config */
#define NET_DVR_SET_NFSCFG			231		/* NFS disk config */

#define NET_DVR_GET_SHOWSTRING_EX	238		//Get Extended OSD Parameters 
#define NET_DVR_SET_SHOWSTRING_EX	239		//Set Extended OSD Parameters
#define NET_DVR_GET_NETCFG_OTHER	244		//Get Network Parameters
#define NET_DVR_SET_NETCFG_OTHER	245		//Set Network Parameters 

//NET_DVR_EMAILCFG
#define NET_DVR_GET_EMAILPARACFG	250		//Get EMAIL parameters
#define NET_DVR_SET_EMAILPARACFG	251		//Setup EMAIL parameters


#define NET_DVR_GET_DDNSCFG_EX		274		//Get Extended DDNS Parameters
#define NET_DVR_SET_DDNSCFG_EX		275		//Set Extended DDNS Parameters


#define	NET_DVR_SET_PTZPOS			292		//Set PTZ Position
#define	NET_DVR_GET_PTZPOS			293		//Get PTZ Position
#define	NET_DVR_GET_PTZSCOPE		294		//Get PTZ Scope


/***************************DS9000 New Commands(_V30) begin *****************************/
//Network(NET_DVR_NETCFG_V30)
#define NET_DVR_GET_NETCFG_V30		    1000		//Get  Network  Parameters
#define NET_DVR_SET_NETCFG_V30		    1001		//Set  Network  Parameters

//Image(NET_DVR_PICCFG_V30)
#define NET_DVR_GET_PICCFG_V30		    1002		//Get Image Parameters
#define NET_DVR_SET_PICCFG_V30		    1003		//Set Image Parameters

//Record(NET_DVR_RECORD_V30)
#define NET_DVR_GET_RECORDCFG_V30	    1004		//Get Record Parameters
#define NET_DVR_SET_RECORDCFG_V30	    1005		//Set Record Parameters

//User(NET_DVR_USER_V30)
#define NET_DVR_GET_USERCFG_V30 	    1006		//Get User Parameters
#define NET_DVR_SET_USERCFG_V30		    1007		//Set User Parameters

//9000DDNS Config(NET_DVR_DDNSPARA_V30)
#define     NET_DVR_GET_DDNSCFG_V30		1010		//Get DDNS (9000Extended)
#define     NET_DVR_SET_DDNSCFG_V30		1011		//Set DDNS (9000Extended)

//EMAIL (NET_DVR_EMAILCFG_V30)
#define NET_DVR_GET_EMAILCFG_V30		1012		//Get EMAIL Configuration
#define NET_DVR_SET_EMAILCFG_V30		1013		//Set EMAIL Configuration

//Cruise (NET_DVR_CRUISE_PARA)
#define 	NET_DVR_GET_CRUISE			1020		
#define 	NET_DVR_SET_CRUISE			1021		


//Alarm input  (NET_DVR_ALARMINCFG_V30)
#define 	NET_DVR_GET_ALARMINCFG_V30			1024		
#define 	NET_DVR_SET_ALARMINCFG_V30			1025

//Alarm output  (NET_DVR_ALARMOUTCFG_V30)
#define 	NET_DVR_GET_ALARMOUTCFG_V30			1026		
#define 	NET_DVR_SET_ALARMOUTCFG_V30			1027

//Video output  (NET_DVR_VIDEOOUT_V30)
#define 	NET_DVR_GET_VIDEOOUTCFG_V30			1028		
#define 	NET_DVR_SET_VIDEOOUTCFG_V30			1029	

//OSD  (NET_DVR_SHOWSTRING_V30)
#define 	NET_DVR_GET_SHOWSTRING_V30			1030		
#define 	NET_DVR_SET_SHOWSTRING_V30			1031

//Exception  (NET_DVR_EXCEPTION_V30)
#define 	NET_DVR_GET_EXCEPTIONCFG_V30		1034		
#define 	NET_DVR_SET_EXCEPTIONCFG_V30		1035

//RS232  (NET_DVR_RS232CFG_V30)
#define 	NET_DVR_GET_RS232CFG_V30			1036		
#define 	NET_DVR_SET_RS232CFG_V30			1037

//Encoding  (NET_DVR_COMPRESSIONCFG_V30)
#define     NET_DVR_GET_COMPRESSCFG_V30	        1040		
#define     NET_DVR_SET_COMPRESSCFG_V30	        1041		

//RS485  (NET_DVR_DECODERCFG_V30)
#define     NET_DVR_GET_DECODERCFG_V30		    1042		//Get Decoder Parameters
#define     NET_DVR_SET_DECODERCFG_V30		    1043		//Set Decoder parameters

//Preview  (NET_DVR_PREVIEWCFG_V30)
#define     NET_DVR_GET_PREVIEWCFG_V30		    1044		//Get Preview Parameters
#define     NET_DVR_SET_PREVIEWCFG_V30		    1045		//Set Preview Parameters

//AUX Preview (NET_DVR_PREVIEWCFG_AUX_V30)
#define     NET_DVR_GET_PREVIEWCFG_AUX_V30		1046		//Get AUX Preview Parameters
#define     NET_DVR_SET_PREVIEWCFG_AUX_V30		1047		//Set AUX Preview Parameters

//IP Channel Configuration (NET_DVR_IPPARACFG)
#define     NET_DVR_GET_IPPARACFG               1048        //Get IP Channel Configuration info 
#define     NET_DVR_SET_IPPARACFG               1049        //Set IP Channel Configuration info 

//IP Alarm In Configuration (NET_DVR_IPALARMINCFG)
#define     NET_DVR_GET_IPALARMINCFG            1050        //Get IP Alarm In Configuration info
#define     NET_DVR_SET_IPALARMINCFG            1051        //Set IP Alarm In Configuration info

//IP Alarm Out Configuration (NET_DVR_IPALARMOUTCFG)
#define     NET_DVR_GET_IPALARMOUTCFG           1052        //Get IP Alarm Out Configuration info  
#define     NET_DVR_SET_IPALARMOUTCFG           1053        //Set IP Alarm Out Configuration info 

//HD management Configuration (NET_DVR_HDCFG)
#define     NET_DVR_GET_HDCFG			        1054	    //Get HD management Configuration
#define     NET_DVR_SET_HDCFG			        1055	    //Get HD management Configuration

//HD Group Configuration (NET_DVR_HDGROUP_CFG)
#define     NET_DVR_GET_HDGROUP_CFG			    1056	    //Get HD Group Configuration Parameters
#define     NET_DVR_SET_HDGROUP_CFG			    1057	    //Set HD Group Configuration Parameters

//Device AudioTalk Configuration(NET_DVR_COMPRESSION_AUDIO)
#define     NET_DVR_GET_COMPRESSCFG_AUD                1058        //Get AudioTalk Configuration Parameters
#define     NET_DVR_SET_COMPRESSCFG_AUD                1059        //Set AudioTalk Configuration Parameters
/***************************DS9000 New Commands(_V30) end *****************************/

/*************************Parameter Configure Commands end*******************************/


/*******************Return Value of File&Log Query API*************************/
#define NET_DVR_FILE_SUCCESS		1000	//Get log information
#define NET_DVR_FILE_NOFIND			1001	//no log
#define NET_DVR_ISFINDING			1002	//on searching
#define	NET_DVR_NOMOREFILE			1003	//no more files
#define	NET_DVR_FILE_EXCEPTION		1004	//Error on log query

/*********************Callback Function Type begin************************/
#define COMM_ALARM					0x1100	//8000 Upload alarm message
#define	COMM_TRADEINFO				0x1500  //ATM DVR transaction information 

#define COMM_ALARM_V30				0x4000	//9000 upload alarm message
#define COMM_IPCCFG			        0x4001	//9000 IPC configuration changed, upload with push mode


/*************Operation Exception**********************/
#define EXCEPTION_EXCHANGE			0x8000	//Network user exception
#define EXCEPTION_AUDIOEXCHANGE		0x8001	//Network voice talk exception
#define EXCEPTION_ALARM				0x8002	//Alarm exception
#define EXCEPTION_PREVIEW			0x8003	//Network preview exception
#define EXCEPTION_SERIAL			0x8004	//Transparent channel exception
#define EXCEPTION_RECONNECT			0x8005	//Network preview reconnected
#define EXCEPTION_ALARMRECONNECT	0x8006	//Alarm reconnected
#define EXCEPTION_SERIALRECONNECT	0x8007	//Transparent channel reconnected
#define EXCEPTION_PLAYBACK	        0x8010	//Playback exception
#define EXCEPTION_DISKFMT	        0x8011	//Hard Disk format exception

/********************Preview Callback Function*********************/
#define NET_DVR_SYSHEAD			1	//System header
#define NET_DVR_STREAMDATA		2	//stream data
#define NET_DVR_AUDIOSTREAMDATA	3	//Audio Stream data
#define NET_DVR_STD_VIDEODATA	4	//Standard video stream data
#define NET_DVR_STD_AUDIODATA	5	//Standard audio stream data 

//Preview Callback
#define NET_DVR_REALPLAYEXCEPTION	111	//Preview exception
#define NET_DVR_REALPLAYNETCLOSE	112	//disconnected while preview
#define NET_DVR_REALPLAY5SNODATA	113	//No data received since start preview 5 seconds ago
#define NET_DVR_REALPLAYRECONNECT	114	//Preview reconnected

/********************Playback Callback*********************/
#define NET_DVR_PLAYBACKOVER		101	//Playback finished
#define NET_DVR_PLAYBACKEXCEPTION	102	//Playback exception
#define NET_DVR_PLAYBACKNETCLOSE	103	//Disconnected while playing
#define NET_DVR_PLAYBACK5SNODATA	104	//No data received since start playback 5 seconds ago.

/*********************Callback Function Type end************************/



/* Device model*/
#define DVR							1				/*Undefined DVR*/
#define ATMDVR						2				/*atm dvr*/
#define DVS							3				/*DVS*/
#define DEC							4				/* 6001D */
#define ENC_DEC						5				/* 6001F */
#define DVR_HC						6				/*8000HC*/
#define DVR_HT						7				/*8000HT*/
#define DVR_HF						8				/*8000HF*/
#define DVR_HS						9				/* 8000HS DVR(no audio) */
#define DVR_HTS						10              /* 8016HTS DVR(no audio) */
#define DVR_HB						11              /* HB DVR(SATA HD) */
#define DVR_HCS						12              /* 8000HCS DVR */
#define DVS_A						13              /* DVS with ATA Hard disk */
#define DVR_HC_S					14              /* 8000HC-S */
#define DVR_HT_S					15              /* 8000HT-S */
#define DVR_HF_S					16              /* 8000HF-S */
#define DVR_HS_S					17              /* 8000HS-S */
#define ATMDVR_S					18              /* ATM-S */
#define LOWCOST_DVR					19				/*7000H Series*/
#define DEC_MAT						20              /*Multichannel Decoder*/
#define DVR_MOBILE					21				/* mobile DVR */                 
#define DVR_HD_S					22              /* 8000HD-S */
#define DVR_HD_SL					23				/* 8000HD-SL */
#define DVR_HC_SL					24				/* 8000HC-SL */
#define DVR_HS_ST					25				/* 8000HS_ST */
#define DVS_HW						26              /* 6000HW */
#define IPCAM						30				/*IP Camera*/

#define MEGA_IPCAM					31				/*Mega Pixels IP Camera*/
#define IPCAM_X62MF					32				/*862MF IP Camera*/
#define IPDOME						40				/*IP Speed Dome*/
#define MEGA_IPDOME                 41              /*Mega Pixels IP Dome*/
#define IPMOD						50				/*IP Model*/
#define DS71XX_H					71				/* DS71XXH_S */
#define DS72XX_H_S					72				/* DS72XXH_S */
#define DS73XX_H_S					73				/* DS73XXH_S */
#define DS81XX_HS_S					81				/* DS81XX_HS_S */
#define DS81XX_HL_S					82				/* DS81XX_HL_S */
#define DS81XX_HC_S					83				/* DS81XX_HC_S */
#define DS81XX_HD_S					84				/* DS81XX_HD_S */
#define DS81XX_HE_S					85				/* DS81XX_HE_S */
#define DS81XX_HF_S					86				/* DS81XX_HF_S */
#define DS81XX_AH_S					87				/* DS81XX_AH_S */
#define DS81XX_AHF_S				88				/* DS81XX_AHF_S */
#define DS90XX_HF_S		            90              /*DS90XX_HF_S*/
#define DS91XX_HF_S					91              /*DS91XX_HF_S*/
#define DS91XX_HD_S					92              /*91XXHD-S(MD)*/

/**********************Device model end***********************/

/*************************************************
Parameters configuration structure(_V30 is for 9000)
**************************************************/

/////////////////////////////////////////////////////////////////////////
//Time correction structure
typedef struct
{
	DWORD dwYear;		//Year
	DWORD dwMonth;		//Month
	DWORD dwDay;		//Day
	DWORD dwHour;		//Hour
	DWORD dwMinute;		//Minute
	DWORD dwSecond;		//Second
}NET_DVR_TIME, *LPNET_DVR_TIME;

//Time Segment(Sub structure)
typedef struct
{
	//Start
    BYTE byStartHour;
	BYTE byStartMin;
	//End
	BYTE byStopHour;
	BYTE byStopMin;
}NET_DVR_SCHEDTIME, *LPNET_DVR_SCHEDTIME;

/*Handling way of Alarm & Exception*/
#define NOACTION			0x0				/*Don't Respond*/
#define WARNONMONITOR		0x1				/*Warning on Monitor*/
#define WARNONAUDIOOUT		0x2				/*Audio Warning*/
#define UPTOCENTER			0x4				/*Upload to center*/
#define TRIGGERALARMOUT		0x8				/*Trigger Alarm Output*/

//Handle Alarm & Exception
typedef struct
{
	DWORD	dwHandleType;	/*Way to handle, result of operation OR*/
	/*0x00: No response*/
	/*0x01: Alarm on monitor*/
	/*0x02: Audio Alarm*/
	/*0x04: Upload to center*/
	/*0x08: Trigger alarm output*/
	/*0x10: Grab Jpeg image and EMail it*/
	BYTE byRelAlarmOut[MAX_ALARMOUT_V30];  
    //Alarm out channel, 1 means trigger this channel
}NET_DVR_HANDLEEXCEPTION_V30, *LPNET_DVR_HANDLEEXCEPTION_V30;

//Handle Alarm & Exception (sub structure)
typedef struct
{
	DWORD	dwHandleType;			/*Way to handle, result of operation OR*/
	/*0x00: No response*/
	/*0x01: Alarm on monitor*/
	/*0x02: Audio Alarm*/
	/*0x04: Upload to center*/
	/*0x08: Trigger alarm output*/
	/*0x10: Grab Jpeg image and EMail it*/
	BYTE byRelAlarmOut[MAX_ALARMOUT]; //Alarm out channel, 1 means trigger this channel
}NET_DVR_HANDLEEXCEPTION, *LPNET_DVR_HANDLEEXCEPTION;

//DVR Device Parameters
typedef struct
{
	DWORD dwSize;
	BYTE sDVRName[NAME_LEN];     //DVR Name
	DWORD dwDVRID;				//DVR ID for IR Control //V1.4(0-99), V1.5(0-255)
	DWORD dwRecycleRecord;		//cycle Record,0:No cycle; 1:cycle
	//The variable below is read only
	BYTE sSerialNumber[SERIALNO_LEN];	//SN
	DWORD dwSoftwareVersion;			//software version,high 16 bits is main version, low 16 bits is hypo-version
	DWORD dwSoftwareBuildDate;			//build date,0xYYYYMMDD
	DWORD dwDSPSoftwareVersion;		    //DSP software version, high 16 bits is main version, low 16 bits is hypo-version
	DWORD dwDSPSoftwareBuildDate;		// DSP software build date,0xYYYYMMDD
	DWORD dwPanelVersion;				// Front panel version, high 16 bits is main version, low 16 bits is hypo-version
	DWORD dwHardwareVersion;	// Hardware version, high 16 bits is main version, low 16 bits is hypo-version
	BYTE byAlarmInPortNum;		//Number of alarm input
	BYTE byAlarmOutPortNum;		//Number of alarm output
	BYTE byRS232Num;			//Number of DVR RS232 ports
	BYTE byRS485Num;			//Number of DVR RS485 ports
	BYTE byNetworkPortNum;		//Number of network ports
	BYTE byDiskCtrlNum;			//Number of DVR hardware controllers
	BYTE byDiskNum;				//DVR Hard disk number
	BYTE byDVRType;				//DVR Model, 1:DVR 2:ATM DVR 3:DVS ......
	BYTE byChanNum;				//DVR channel number
	BYTE byStartChan;			//First channel's No. e.g., DVS-1,DVR - 1
	BYTE byDecordChans;			//Number of decoding channels
	BYTE byVGANum;				//Number of VGA ports
	BYTE byUSBNum;				//Number of USB ports
    BYTE byAuxoutNum;			//Number of AUX ports
    BYTE byAudioNum;			//Number of audio ports
    BYTE byIPChanNum;			//Maximum number of IP channels
}NET_DVR_DEVICECFG, *LPNET_DVR_DEVICECFG;

/*
IP Address
*/
typedef struct
{		
	char	sIpV4[16];						/* IPv4 Address */
	BYTE	byRes[128];						/* Reserved */
}NET_DVR_IPADDR, *LPNET_DVR_IPADDR;


/*
Network structure (9000)
*/
typedef struct 
{
	NET_DVR_IPADDR	struDVRIP;          					//DVR IP address
	NET_DVR_IPADDR	struDVRIPMask;							//DVR IP Mask
	DWORD	dwNetInterface;   								//Network port, 1-10MBase-T 2-10MBase-T full duplex  3-100MBase-TX 4-100M full duplex  5-10M/100M adaptive
	WORD	wDVRPort;										//Port
	WORD	wMTU;											//MTU, 1500 by default
	BYTE	byMACAddr[MACADDR_LEN];							//MAC address
}NET_DVR_ETHERNET_V30, *LPNET_DVR_ETHERNET_V30;

/*
Network data structure(Sub structure)
*/
typedef struct
{
	char sDVRIP[16];          //DVR IP address
	char sDVRIPMask[16];      //DVR IP Mask
	DWORD dwNetInterface;     //Network interface 1-10MBase-T 2-10MBase-T full duplex 3-100MBase-TX 4-100M full duplex 5-10M/100M adaptive
	WORD wDVRPort;		      //Port
	BYTE byMACAddr[MACADDR_LEN]; //Mac address
}NET_DVR_ETHERNET;

//pppoe structure
typedef struct 
{
	DWORD	dwPPPOE;										//0-disable,1-enable
	BYTE	sPPPoEUser[NAME_LEN];							//PPPoE user name
	char	sPPPoEPassword[PASSWD_LEN];						// PPPoE password
	NET_DVR_IPADDR	struPPPoEIP;							//PPPoE IP address
}NET_DVR_PPPOECFG, *LPNET_DVR_PPPOECFG;

//Network Configure Structure (9000DVR extended)
typedef struct
{	
	DWORD dwSize;
	NET_DVR_ETHERNET_V30	struEtherNet[MAX_ETHERNET];		//Network Port
	NET_DVR_IPADDR	struRes1[2];							/*Reserved*/
	NET_DVR_IPADDR	struAlarmHostIpAddr;					/*IP address of Alarm Host */
	WORD	wRes2[2];										/* Reserved */
	WORD	wAlarmHostIpPort;								/* Port of Alarm Host */
	BYTE    byUseDhcp;                                      /* Enable DHCP or not 0xff-invalid 0-disable 1-enable*/
	BYTE	byRes3;
	NET_DVR_IPADDR	struDnsServer1IpAddr;					/* IP address of DNS 1 */
	NET_DVR_IPADDR	struDnsServer2IpAddr;					/* IP address of DNS 2 */
	BYTE	byIpResolver[MAX_DOMAIN_NAME];					/* IP address or domain name of analysis server*/
	WORD	wIpResolverPort;								/* Port of IP analysis server*/
	WORD	wHttpPortNo;									/* HTTP port */
	NET_DVR_IPADDR	struMulticastIpAddr;					/* Multicast group address */
	NET_DVR_IPADDR	struGatewayIpAddr;						/* Gateway address */
	NET_DVR_PPPOECFG struPPPoE;	
    BYTE    byRes[64];
} NET_DVR_NETCFG_V30, *LPNET_DVR_NETCFG_V30;

//Network Configure Structure
typedef struct
{
	DWORD dwSize;
	NET_DVR_ETHERNET struEtherNet[MAX_ETHERNET];		/* etwork Port */
	char sManageHostIP[16];		//IP address of remote management host
	WORD wManageHostPort;		//Port of remote management Host
	char sIPServerIP[16];       //Address of IPServer
	char sMultiCastIP[16];     //Multicast group address
	char sGatewayIP[16];       	//Gateway address
	char sNFSIP[16];			//IP address of NFS host
	BYTE sNFSDirectory[PATHNAME_LEN];//NFS directory
	DWORD dwPPPOE;				//0-disable,1-enable
	BYTE sPPPoEUser[NAME_LEN];	//PPPoE username
	char sPPPoEPassword[PASSWD_LEN];// PPPoE password
	char sPPPoEIP[16];			//PPPoE IP address (read only)
	WORD wHttpPort;				//HTTP port
}NET_DVR_NETCFG, *LPNET_DVR_NETCFG;

//Channel Image structure
//Motion detection structure(sub structure)(9000 extended)
typedef struct 
{
	BYTE byMotionScope[64][96];									/*Motion detection area,0-96 bits stand for 64 lines and there are 96*64 small areas, 1--it is motion detection area,0--not*/
	BYTE byMotionSensitive;										/*sensitive grade of motion detection, 0 - 5(5 is most sensitive), oxff turn off*/
	BYTE byEnableHandleMotion;									/* Process motion alarm  0No 1Yes*/ 
	BYTE byPrecision;											/* the precision of motion detection : 0--16*16, 1--32*32, 2--64*64 ... */
	char reservedData;	
	NET_DVR_HANDLEEXCEPTION_V30 struMotionHandleType;				/* The way to process */
	NET_DVR_SCHEDTIME struAlarmTime[MAX_DAYS][MAX_TIMESEGMENT_V30]; /*Guard time*/
	BYTE byRelRecordChan[MAX_CHANNUM_V30];									/* Channel triggered to record*/
}NET_DVR_MOTION_V30, *LPNET_DVR_MOTION_V30;

//Motion detection structure(sub structure)
typedef struct 
{
	BYTE byMotionScope[18][22];	/*motion detection area, 22*18 blocks in total, 1--it's motion detection area, 0--not*/
	BYTE byMotionSensitive;		/*sensitive grade of motion detection, 0 - 5(5 is most sensitive), oxff turn off*/
	BYTE byEnableHandleMotion;	/* process motion detection or not */
	char reservedData[2];
	NET_DVR_HANDLEEXCEPTION strMotionHandleType;	/* methoder to process alarm */
	NET_DVR_SCHEDTIME struAlarmTime[MAX_DAYS][MAX_TIMESEGMENT];//Guard time
	BYTE byRelRecordChan[MAX_CHANNUM];				//Channel triggered to record*/
}NET_DVR_MOTION, *LPNET_DVR_MOTION;

//Tamper Alarm (sub structure)(9000 extended)  area size: 704*576
typedef struct 
{
	DWORD dwEnableHideAlarm;				/* Enable tamper alarm or not ,0-disable,1-low sensitivity 2-Middle 3-High*/
	WORD wHideAlarmAreaTopLeftX;			/* X-coordinate of tamper area */
	WORD wHideAlarmAreaTopLeftY;			/* Y-coordinate of tamper area */
	WORD wHideAlarmAreaWidth;				/* Width of tampered area */
	WORD wHideAlarmAreaHeight;				/* Height of tampered area*/
	NET_DVR_HANDLEEXCEPTION_V30 strHideAlarmHandleType;	/* Way to handle alarm */
	NET_DVR_SCHEDTIME struAlarmTime[MAX_DAYS][MAX_TIMESEGMENT_V30];//Guard time
}NET_DVR_HIDEALARM_V30, *LPNET_DVR_HIDEALARM_V30;

//Tamper Alarm (sub structure) area size: 704*576
typedef struct 
{
	DWORD dwEnableHideAlarm;				/* Enable tamper alarm or not ,0-disable,1-low sensitivity 2-Middle 3-High*/
	WORD wHideAlarmAreaTopLeftX;			/* X-coordinate of tamper area */
	WORD wHideAlarmAreaTopLeftY;			/* Y-coordinate of tamper area */
	WORD wHideAlarmAreaWidth;				/* Width of tampered area */
	WORD wHideAlarmAreaHeight;				/* Height of tampered area*/
	NET_DVR_HANDLEEXCEPTION strHideAlarmHandleType;	/* Way to handle the alarm */
	NET_DVR_SCHEDTIME struAlarmTime[MAX_DAYS][MAX_TIMESEGMENT];//Guard time
}NET_DVR_HIDEALARM, *LPNET_DVR_HIDEALARM;

//Signal Lost Alarm(sub structure)(9000 extended)
typedef struct 
{
	BYTE byEnableHandleVILost;	/* Respond the alarm or not */
	NET_DVR_HANDLEEXCEPTION_V30 strVILostHandleType;	/* Way to respond*/
	NET_DVR_SCHEDTIME struAlarmTime[MAX_DAYS][MAX_TIMESEGMENT_V30];//Guard time
}NET_DVR_VILOST_V30, *LPNET_DVR_VILOST_V30;

//Signal Lost Alarm(sub structure)
typedef struct 
{
	BYTE byEnableHandleVILost;	/* Respond the alarm or not */
	NET_DVR_HANDLEEXCEPTION strVILostHandleType;	/* Way to respond*/
	NET_DVR_SCHEDTIME struAlarmTime[MAX_DAYS][MAX_TIMESEGMENT];//Guard time
}NET_DVR_VILOST, *LPNET_DVR_VILOST;

//Tampered Area(sub structure)
typedef struct 
{
	WORD wHideAreaTopLeftX;				/* X-coordinate of tamper area */
	WORD wHideAreaTopLeftY;				/* Y-coordinate of tamper area */
	WORD wHideAreaWidth;				/* Width of tampered area */
	WORD wHideAreaHeight;				/* Height of tampered area*/
}NET_DVR_SHELTER, *LPNET_DVR_SHELTER;

typedef struct
{
	BYTE byBrightness;  	/*Brightness,0-255*/
	BYTE byContrast;    	/*contrast,0-255*/	
	BYTE bySaturation;  	/*Saturation,0-255*/
	BYTE byHue;    			/*Hue,0-255*/
}NET_DVR_COLOR, *LPNET_DVR_COLOR;


//Video Structure(9000 extended)
typedef struct
{
	DWORD dwSize;
	BYTE sChanName[NAME_LEN];
	DWORD dwVideoFormat;	/* Read only, Video Standard 1-NTSC 2-PAL*/
	NET_DVR_COLOR struColor;//	image parameter
	char reservedData [60];/*Reserved*/
	//Display Channel Name
	DWORD dwShowChanName; // Display channel name or not,0-no,1-display size = 704*576
	WORD wShowNameTopLeftX;				/* X-coordinate of display position */
	WORD wShowNameTopLeftY;				/* Y-coordinate of display position  */
	//Signal lost Alarm
	NET_DVR_VILOST_V30 struVILost;
	NET_DVR_VILOST_V30 struRes;		/*Reserved*/
	//Motion detection
	NET_DVR_MOTION_V30 struMotion;
	//Tamper alarm
	NET_DVR_HIDEALARM_V30 struHideAlarm;
	//Tampered Area 704*576
	DWORD dwEnableHide;		/* Enable Tamper Alarm ,0-disable,1-enable*/
	NET_DVR_SHELTER struShelter[MAX_SHELTERNUM];
	//OSD
	DWORD dwShowOsd;		// Display OSD or not,0-No OSD,1-Display Area for display: 704*576
	WORD wOSDTopLeftX;				/* X-coordinate of OSD */
	WORD wOSDTopLeftY;				/* Y-coordinate of OSD*/
	BYTE byOSDType;					/* OSD Type (format of Year/Month/Day) */
	/* 0: XXXX-XX-XX Year Month Day */
	/* 1: XX-XX-XXXX Month Day Year */
	/* 2: XXXXYearXXNonthXXDay */
	/* 3: XXMonthXXDayXXXXYear */
	/* 4: XX-XX-XXXX Day Month Year*/
	/* 5: XXDayXXMonthXXXXYear */
	BYTE byDispWeek;				/* display Week */
	BYTE byOSDAttrib;				/* OSD attribute: TransparentFlash */
	/* 0: No OSD */
	/* 1: Transparent,Flash */
	/* 2: Transparent,not Flash */
	/* 3: Flash,not Transparent */
	/* 4: not Transparent, not Flash */
    BYTE byHourOSDType;				/* :24-Hour system,12-Hour system */
	BYTE byRes[64];
}NET_DVR_PICCFG_V30, *LPNET_DVR_PICCFG_V30;

//Video Structure(SDK_V14 extended)
typedef struct 
{
	DWORD dwSize;
	BYTE sChanName[NAME_LEN];
	DWORD dwVideoFormat;	/* Read only, Video Standard 1-NTSC 2-PAL*/
	BYTE byBrightness;  	/*Brightness,0-255*/
	BYTE byContrast;    	/*contrast,0-255*/	
	BYTE bySaturation;  	/*Saturation,0-255*/
	BYTE byHue;    			/*Hue,0-255*/
	//Display Channel Name
	DWORD dwShowChanName; // Display channel name or not,0-no,1-display size = 704*576
	WORD wShowNameTopLeftX;				/* X-coordinate of display position */
	WORD wShowNameTopLeftY;				/* Y-coordinate of display position  */
	//Signal lost Alarm
	NET_DVR_VILOST struVILost;
	//Motion Detection
	NET_DVR_MOTION struMotion;
	//Tamper Alarm
	NET_DVR_HIDEALARM struHideAlarm;
	//Tamper Area size: 704*576
	DWORD dwEnableHide;		/* Enable Tamper Alarm ,0-disable,1-enable**/
	NET_DVR_SHELTER struShelter[MAX_SHELTERNUM];
	//OSD
	DWORD dwShowOsd;				// Display OSD or not,0-No OSD,1-Display Area for display: 704*576
	WORD wOSDTopLeftX;				/* X-coordinate of OSD */
	WORD wOSDTopLeftY;				/* Y-coordinate of OSD*/
	BYTE byOSDType;					/* OSD Type (format of Year/Month/Day) */
	/* 0: XXXX-XX-XX Year/Month/Day */
	/* 1: XX-XX-XXXX Month/Day/Year */
	/* 2: XXXXYearXXNonthXXDay */
	/* 3: XXMonthXXDayXXXXYear */
	/* 4: XX-XX-XXXX Day Month Year*/
	/* 5: XXDayXXMonthXXXXYear */
	BYTE byDispWeek;				/* display Week */
	BYTE byOSDAttrib;				/* OSD attribute: TransparentFlash */
	/* 0: No OSD */
	/* 1: Transparent,Flash */
	/* 2: Transparent,not Flash */
	/* 3: Flash,not Transparent */
	/* 4: not Transparent, not Flash */
	BYTE byHourOSDType;	//hour0-24 hours1-am/pm
}NET_DVR_PICCFG_EX, *LPNET_DVR_PICCFG_EX;

//Video Structure(SDK_V14 extended)
typedef struct 
{
	DWORD dwSize;
	BYTE sChanName[NAME_LEN];
	DWORD dwVideoFormat;	/* Read only, Video Standard 1-NTSC 2-PAL*/
	BYTE byBrightness;  	/*Brightness,0-255*/
	BYTE byContrast;    	/*contrast,0-255*/	
	BYTE bySaturation;  	/*Saturation,0-255*/
	BYTE byHue;    			/*Hue,0-255*/
	//Display Channel Name
	DWORD dwShowChanName; // Display channel name or not,0-no,1-display size = 704*576
	WORD wShowNameTopLeftX;				/* X-coordinate of display position */
	WORD wShowNameTopLeftY;				/* Y-coordinate of display position  */
	//Signal lost Alarm
	NET_DVR_VILOST struVILost;
	//Motion Detection
	NET_DVR_MOTION struMotion;
	//Tamper Alarm
	NET_DVR_HIDEALARM struHideAlarm;
	//Tamper Area size: 704*576
	DWORD dwEnableHide;		/* Enable Tamper Alarm ,0-disable,1-enable*/
	WORD wHideAreaTopLeftX;				/* X-coordinate of tampered area*/
	WORD wHideAreaTopLeftY;				/* Y-coordinate of tampered area */
	WORD wHideAreaWidth;				/* Width of tampered area */
	WORD wHideAreaHeight;				/* Height of tampered area */
	//OSD
	DWORD dwShowOsd;				// Display OSD or not,0-No OSD,1-Display Area for display: 704*576
	WORD wOSDTopLeftX;				/* X-coordinate of OSD */
	WORD wOSDTopLeftY;				/* Y-coordinate of OSD*/
	BYTE byOSDType;					/* OSD Type (format of Year/Month/Day) */
	/* 0: XXXX-XX-XX Year/Month/Day */
	/* 1: XX-XX-XXXX Month/Day/Year */
	/* 2: XXXXYearXXNonthXXDay */
	/* 3: XXMonthXXDayXXXXYear */
	/* 4: XX-XX-XXXX Day Month Year*/
	/* 5: XXDayXXMonthXXXXYear */
	BYTE byDispWeek;				/* display Week */
	BYTE byOSDAttrib;				/* OSD attribute: TransparentFlash */
	/* 0: No OSD */
	/* 1: Transparent,Flash */
	/* 2: Transparent,not Flash */
	/* 3: Flash,not Transparent */
	/* 4: not Transparent, not Flash */
	char reservedData2;
}NET_DVR_PICCFG, *LPNET_DVR_PICCFG;

//Encoding Parameters(Sub Strut)(9000 extended)
typedef struct 
{
	BYTE byStreamType;		//Stream type 0-video, 1-video&aduio, when it stands for compression parameters, the hightest bit stands for whether adopt encoding parameters
	BYTE byResolution;  	//Resolution 0-DCIF 1-CIF, 2-QCIF, 3-4CIF, 4-2CIF 5(reserved) 16-VGA(640*480) 17-UXGA(1600*1200) 18-SVGA (800*600)19-HD720p(1280*720)20-XVGA  21-HD900p
	BYTE byBitrateType;		//Bitrate Type 0:CBR1:VBR
	BYTE byPicQuality;		//Image Quality 0-best 1-much better 2-better 3-Normal 4-worse 5-worst
	DWORD dwVideoBitrate; 	//video bit rate 0-reserved 1-16K 2-32K 3-48k 4-64K 5-80K 6-96K 7-128K 8-160k 9-192K 10-224K 11-256K 12-320K
	// 13-384K 14-448K 15-512K 16-640K 17-768K 18-896K 19-1024K 20-1280K 21-1536K 22-1792K 23-2048K
	//if The highest bit(31 bit) is 1, it stands for user defined bit rate, 0-30 is the value of bit rate
	DWORD dwVideoFrameRate;	//Frame rate 0-full; 1-1/16; 2-1/8; 3-1/4; 4-1/2; 5-1; 6-2; 7-4; 8-6; 9-8; 10-10; 11-12; 12-16; 13-20;14-15; 15-18; 16-22;
	WORD  wIntervalFrameI;  //interval of I frame
	//2006-08-11 Add single P frame
	BYTE  byIntervalBPFrame;//0-BBP frame; 1-BP frame; 2-P frame only.
	BYTE  byres1;        //reserve
	BYTE  byVideoEncType;   //Video Code Type: 0-hik 264;1-standard H264;2-standard MPEG4
	BYTE  byAudioEncType;   //Audio Code Type: 0-OggVorbis
	BYTE  byres[10];//reserve
}NET_DVR_COMPRESSION_INFO_V30, *LPNET_DVR_COMPRESSION_INFO_V30;

//Encoding Parameters (9000 extended)
typedef struct 
{
	DWORD dwSize;
	NET_DVR_COMPRESSION_INFO_V30 struNormHighRecordPara;    //Record, corresponding to 8000's nomal
	NET_DVR_COMPRESSION_INFO_V30 struRes;					//Reserved char reserveData[28];
    NET_DVR_COMPRESSION_INFO_V30 struEventRecordPara;       //Encoding parameters tiggered by Events
	NET_DVR_COMPRESSION_INFO_V30 struNetPara;               //network transfer
}NET_DVR_COMPRESSIONCFG_V30, *LPNET_DVR_COMPRESSIONCFG_V30;

//Encoding Parameters(Sub Strut)
typedef struct 
{
	BYTE byStreamType;		//Stream type 1-video, 3-video&aduio, when it stands for compression parameters, the hightest bit stands for whether adopt encoding parameters
	BYTE byResolution;  	//Resolution 0-DCIF 1-CIF, 2-QCIF, 3-4CIF, 4-2CIF, 5-2QCIF(352X144)(for Mobile DVR)
	BYTE byBitrateType;		//Bit rate type 0:VBR1:CBR
	BYTE  byPicQuality;		//Image Quality 0-best 1-much better 2-better 3-Normal 4-worse 5-worst
	DWORD dwVideoBitrate; 	//video bit rate 0-reserved 1-16K(reserved) 2-32K 3-48k 4-64K 5-80K 6-96K 7-128K 8-160k 9-192K 10-224K 11-256K 12-320K
							// 13-384K 14-448K 15-512K 16-640K 17-768K 18-896K 19-1024K 20-1280K 21-1536K 22-1792K 23-2048K
							//if The highest bit(31 bit) is 1, it stands for user defined bit rate, 0-30 is the value of bit rate(MIN-32K MAX-8192K)
	DWORD dwVideoFrameRate;	//Frame rate 0-full; 1-1/16; 2-1/8; 3-1/4; 4-1/2; 5-1; 6-2; 7-4; 8-6; 9-8; 10-10; 11-12; 12-16; 13-20;
}NET_DVR_COMPRESSION_INFO, *LPNET_DVR_COMPRESSION_INFO;

//Encoding Parameters
typedef struct 
{
	DWORD dwSize;
	NET_DVR_COMPRESSION_INFO struRecordPara; //Record triggered by events
	NET_DVR_COMPRESSION_INFO struNetPara;	//Network transfer(reserved)
}NET_DVR_COMPRESSIONCFG, *LPNET_DVR_COMPRESSIONCFG;

//Encoding Parameters(Sub Strut)(extended) Add I Frame interval
typedef struct 
{
	BYTE byStreamType;		//Stream type 1-video, 3-video&aduio,
	BYTE byResolution; 		//Resolution 0-DCIF 1-CIF, 2-QCIF, 3-4CIF, 4-2CIF, 5-2QCIF(352X144)(for Mobile DVR)
	BYTE byBitrateType;		//Bit rate type 0:VBR1:CBR
	BYTE  byPicQuality;		//Image Quality 0-best 1-much better 2-better 3-Normal 4-worse 5-worst
	DWORD dwVideoBitrate; 	//video bit rate 0-reserved 1-16K(reserved) 2-32K 3-48k 4-64K 5-80K 6-96K 7-128K 8-160k 9-192K 10-224K 11-256K 12-320K
	// 13-384K 14-448K 15-512K 16-640K 17-768K 18-896K 19-1024K 20-1280K 21-1536K 22-1792K 23-2048K
							//if The highest bit(31 bit) is 1, it stands for user defined bit rate, 0-30 is the value of bit rate(MIN-32K MAX-8192K)
	DWORD dwVideoFrameRate;	//Frame rate 0-full; 1-1/16; 2-1/8; 3-1/4; 4-1/2; 5-1; 6-2; 7-4; 8-6; 9-8; 10-10; 11-12; 12-16; 13-20,14-15, 15-18, 16-22;
	WORD  wIntervalFrameI;  //I Frame interval
	//2006-08-11 Add single P frame
	BYTE  byIntervalBPFrame;//0-BBP frame; 1-BP frame; 2-P frame only.
	BYTE  byRes;
}NET_DVR_COMPRESSION_INFO_EX, *LPNET_DVR_COMPRESSION_INFO_EX;

//Encoding Parameters (extended)
typedef struct 
{
	DWORD dwSize;
	NET_DVR_COMPRESSION_INFO_EX struRecordPara; //Record
	NET_DVR_COMPRESSION_INFO_EX struNetPara;	//Netword Transfer
}NET_DVR_COMPRESSIONCFG_EX, *LPNET_DVR_COMPRESSIONCFG_EX;


//Parameters Configure of Recording in Time segment (Sub Strut)
typedef struct 
{
	NET_DVR_SCHEDTIME struRecordTime;
	BYTE byRecordType;	//0:Time Record1:Motion detection2:Alarm record3:Motion|alarm4:Motion&Alarm, 5:Triggered by Commands, 6: Manual Record
	char reservedData[3];
}NET_DVR_RECORDSCHED, *LPNET_DVR_RECORDSCHED;

//Record All-day 
typedef struct 
{
	WORD wAllDayRecord;				/* Enable record all-day or not;0-disable,1-enable*/
	BYTE byRecordType;				//0:Time Record1:Motion detection2:Alarm record3:Motion|alarm4:Motion&Alarm, 5:Triggered by Commands, 6: Manual Record
	char reservedData;
}NET_DVR_RECORDDAY, *LPNET_DVR_RECORDDAY;

//Recording Parameters (9000 extended)
typedef struct 
{
	DWORD	dwSize;
	DWORD	dwRecord;  						/*Record or not 0-not 1-Record*/
	NET_DVR_RECORDDAY	struRecAllDay[MAX_DAYS];
	NET_DVR_RECORDSCHED	struRecordSched[MAX_DAYS][MAX_TIMESEGMENT_V30];
	DWORD	dwRecordTime;					/* post record time  0-5Seconds 1-20Seconds 2-30Seconds 3-1 Minutes 4-2Minutes 5-5Minutes 6-10Minutes*/
	DWORD	dwPreRecordTime;				/* Pre-record time 0-disable 1-5Seconds 2-10Seconds 3-15Seconds 4-20Seconds 5-25Seconds 6-30Seconds 7-0xffffffff */
	DWORD	dwRecorderDuration;				/*  */
	BYTE	byRedundancyRec;				/*Redundancy record to backup important data0/1*/
	BYTE	byAudioRec;						/*Record audio or not*/
	BYTE	byReserve[10];	
}NET_DVR_RECORD_V30, *LPNET_DVR_RECORD_V30;

//Recording Parameters
typedef struct 
{
	DWORD dwSize;
	DWORD dwRecord;  	/*Record or not 0-not 1-Record*/
	NET_DVR_RECORDDAY struRecAllDay[MAX_DAYS];
	NET_DVR_RECORDSCHED struRecordSched[MAX_DAYS][MAX_TIMESEGMENT];
	DWORD dwRecordTime;		/* Pre-record time*/
	DWORD dwPreRecordTime;	/* Pre-record time 0-disable 1-5Seconds 2-10Seconds 3-15Seconds 4-20Seconds 5-25Seconds 6-30Seconds 7-0xffffffff (A.F.A.P)*/
}NET_DVR_RECORD, *LPNET_DVR_RECORD;

//PTZ protocol structure configuration
typedef struct
{ 
    DWORD dwType;               /*Type value of decoder, increase from 1 by degrees*/    
    BYTE  byDescribe[DESC_LEN]; /*Description of decoder, same with 8000*/    
}NET_DVR_PTZ_PROTOCOL;

typedef struct
{    
    DWORD   dwSize;    
    NET_DVR_PTZ_PROTOCOL struPtz[PTZ_PROTOCOL_NUM];/*200 PTZ protocols in total*/    
    DWORD   dwPtzNum;           /*Number of valid ptz protocolStart from 0*/
    BYTE    byRes[8];
}NET_DVR_PTZCFG, *LPNET_DVR_PTZCFG;
/***************************PTZ Protocol(end)******************************/

//PTZ configuration (9000 extended)
typedef struct 
{
	DWORD dwSize;
	DWORD dwBaudRate;//Baud rate(bps)0501752110315043005600612007240084800996001019200 11384001257600137680014115.2k;
	BYTE byDataBit;// Data bit 05Seconds16bit27bit38bit;
	BYTE byStopBit;// Stop bit 01bit12bit;
	BYTE byParity;// Parity 0No parity1odd2even;
	BYTE byFlowcontrol;// flow control: 0None1software ,2-Hardware
	WORD wDecoderType;//Decoder Type, corresponding to PTZ list
	WORD wDecoderAddress;	/*Decoder address:0 - 255*/
	BYTE bySetPreset[MAX_PRESET_V30];		/* Configure Preset or not,0-No,1-Yes*/
	BYTE bySetCruise[MAX_CRUISE_V30];		/* Configure Cruise or not: 0-No,1-Yes */
	BYTE bySetTrack[MAX_TRACK_V30];		    /* Configure Track or not,0-No,1-Yes*/
}NET_DVR_DECODERCFG_V30, *LPNET_DVR_DECODERCFG_V30;

//PTZ decoder configuration
typedef struct 
{
	DWORD dwSize;
	DWORD dwBaudRate;//Baud rate(bps)0501752110315043005600612007240084800996001019200 11384001257600137680014115.2k;
	BYTE byDataBit;// Data bit 05bit16bit27bit38bit;
	BYTE byStopBit;// Stop bit 01bit12bit;
	BYTE byParity;// Parity 0No parity1odd2even;
	BYTE byFlowcontrol;// Flow control: 0None1software ,2-Hardware

	WORD wDecoderType;      //Decoder Type, 0YouLi1LiLin-10162LiLin-8203Pelco-p4DM DynaColor5HD6006JC-41167Pelco-d WX8Pelco-d PICO
	WORD wDecoderAddress;	/*Decoder Address:0 - 255*/
	BYTE bySetPreset[MAX_PRESET];		/* Configure Preset or not,0-No,1-Yes*/
	BYTE bySetCruise[MAX_CRUISE];		/* Configure Cruise or not: 0-No,1-Yes */
	BYTE bySetTrack[MAX_TRACK];			 /* Configure Track or not,0-No,1-Yes*/
}NET_DVR_DECODERCFG, *LPNET_DVR_DECODERCFG;

//ppp parameters configuration(Sub Struct)
typedef struct 
{
	NET_DVR_IPADDR struRemoteIP;	//Remote IP
	NET_DVR_IPADDR struLocalIP;		//Local IP
	char sLocalIPMask[16];			//Local Mask
	BYTE sUsername[NAME_LEN];		/* Username */
	BYTE sPassword[PASSWD_LEN];		/* Password */
	BYTE byPPPMode;					//PPP mode, 0active1passive
	BYTE byRedial;					//Callback or not 0-No,1-Yes
	BYTE byRedialMode;				//Callback,0-user specified,1-preseted number
	BYTE byDataEncrypt;				//Encrypt Data ,0-No,1-Yes
	DWORD dwMTU;					//MTU
	char sTelephoneNumber[PHONENUMBER_LEN];   //Telephone number
}NET_DVR_PPPCFG_V30, *LPNET_DVR_PPPCFG_V30;

//ppp parameters configuration(Sub Struct)
typedef struct 
{
	char sRemoteIP[16];				//Remote IP
	char sLocalIP[16];				//Local IP
	char sLocalIPMask[16];			//Local Mask
	BYTE sUsername[NAME_LEN];		/* Username */
	BYTE sPassword[PASSWD_LEN];		/* Password */
	BYTE byPPPMode;					//PPP mode, 0active1passive
	BYTE byRedial;					//Callback or not 0-No,1-Yes
	BYTE byRedialMode;				//Callback,0-user specified,1-preseted number
	BYTE byDataEncrypt;				//Encrypt Data ,0-No,1-Yes
	DWORD dwMTU;					//MTU
	char sTelephoneNumber[PHONENUMBER_LEN];   //Telephone number
}NET_DVR_PPPCFG, *LPNET_DVR_PPPCFG;

//RS232 Configuration(9000 extended)
typedef struct
{
 	DWORD dwBaudRate;//Baud rate(bps)0501752110315043005600612007240084800996001019200 11384001257600137680014115.2k;
	BYTE byDataBit;// Data bit 05bit16bit27bit38bit;
	BYTE byStopBit;// Stop bit 01bit12bit;
	BYTE byParity;// Parity 0No parity1odd2even;
	BYTE byFlowcontrol;// Flow control: 0None1software ,2-Hardware
    DWORD dwWorkMode;   /* Word mode0232 for PPP dial1232 for parameter control2for transparent channel */
}NET_DVR_SINGLE_RS232;

//RS232 Configuration(9000 extended)
typedef struct 
{
	DWORD dwSize;
    NET_DVR_SINGLE_RS232 struRs232;
	BYTE byRes[84]; 
	NET_DVR_PPPCFG_V30 struPPPConfig;
}NET_DVR_RS232CFG_V30, *LPNET_DVR_RS232CFG_V30;

//RS232 Configuration
typedef struct 
{
	DWORD dwSize;
	DWORD dwBaudRate;//Baud rate(bps)0501752110315043005600612007240084800996001019200 11384001257600137680014115.2k;
	BYTE byDataBit;// Data bit 05bit16bit27bit38bit;
	BYTE byStopBit;// Stop bit 01bit12bit;
	BYTE byParity;// Parity 0No parity1odd2even;
	BYTE byFlowcontrol;// Flow control: 0None1software ,2-Hardware
	DWORD dwWorkMode;   /* Word mode0232 for PPP dial1232 for parameter control2for transparent channel */
	NET_DVR_PPPCFG struPPPConfig;
}NET_DVR_RS232CFG, *LPNET_DVR_RS232CFG;

//Alarm Input Configuration(9000 extended)
typedef struct 
{
	DWORD dwSize;
	BYTE sAlarmInName[NAME_LEN];	/* Name */
	BYTE byAlarmType;	            //Alarm Type,0:normally open,1:normally close
	BYTE byAlarmInHandle;	        /* Handle alarm or not 0-No 1-Yes*/
    BYTE byRes1[2];			
	NET_DVR_HANDLEEXCEPTION_V30 struAlarmHandleType;	/* the Way to handle alarm  */
	NET_DVR_SCHEDTIME struAlarmTime[MAX_DAYS][MAX_TIMESEGMENT_V30];//Guard time
	BYTE byRelRecordChan[MAX_CHANNUM_V30];		//Channel triggered to record, 1--trigger
	BYTE byEnablePreset[MAX_CHANNUM_V30];		/* Call preset or not 0-No,1-Yes*/
	BYTE byPresetNo[MAX_CHANNUM_V30];			/* Preset No. One alarm input can trigger several presets, 0xff-disable*/
	BYTE byRes2[192];							/*Reserved*/
	BYTE byEnableCruise[MAX_CHANNUM_V30];		/* Call Cruise or not 0-No,1-Yes*/
	BYTE byCruiseNo[MAX_CHANNUM_V30];			/* Cruise No.*/
	BYTE byEnablePtzTrack[MAX_CHANNUM_V30];		/* Call Track or not 0-No,1-Yes*/
	BYTE byPTZTrack[MAX_CHANNUM_V30];			/* Track No. */
    BYTE byRes3[16];
}NET_DVR_ALARMINCFG_V30, *LPNET_DVR_ALARMINCFG_V30;

//Alarm Input Configuration
typedef struct 
{
	DWORD dwSize;
	BYTE sAlarmInName[NAME_LEN];	/* Name */
	BYTE byAlarmType;				//Alarm Type,0:normally open,1:normally close
	BYTE byAlarmInHandle;			/* Handle alarm or not 0-No 1-Yes*/
	NET_DVR_HANDLEEXCEPTION struAlarmHandleType;	/* the Way to handle alarm  */
	NET_DVR_SCHEDTIME struAlarmTime[MAX_DAYS][MAX_TIMESEGMENT];//Guard time
	BYTE byRelRecordChan[MAX_CHANNUM];		//Channel triggered to record, 1--trigger
	BYTE byEnablePreset[MAX_CHANNUM];		/* Call preset or not 0-No,1-Yes*/
	BYTE byPresetNo[MAX_CHANNUM];			/* Preset No. One alarm input can trigger several presets, set 0xff to disable*/
	BYTE byEnableCruise[MAX_CHANNUM];		/* Call Cruise or not 0-No,1-Yes*/
	BYTE byCruiseNo[MAX_CHANNUM];			/* Cruise No.*/
	BYTE byEnablePtzTrack[MAX_CHANNUM];		/* Call Track or not 0-No,1-Yes*/
	BYTE byPTZTrack[MAX_CHANNUM];			/* Track No. */
}NET_DVR_ALARMINCFG, *LPNET_DVR_ALARMINCFG;


//Upload Alarm Information (9000 extended)
typedef struct 
{
	DWORD dwAlarmType;/*0-sensor alarm;1-hard disk full;2-video lost;3-motion detection;4-hard disk unformatted;5-hard disk error;6-tampering detection;7-unmatched video output standard;8-illegal operation;;0xa-GPS information(for mobile DVR)*/
	DWORD dwAlarmInputNumber;/*Alarm input Port*/
	BYTE byAlarmOutputNumber[MAX_ALARMOUT_V30];/*State of Alarm output channel1--Triggered*/
	BYTE byAlarmRelateChannel[MAX_CHANNUM_V30];/*channels triggered to record1-recording, dwAlarmRelateChannel[0] is the first channel*/
	BYTE byChannel[MAX_CHANNUM_V30];/*If the dwAlarmType is 2,3 or 6it stands for channeldwChannel[0] is the first channel*/
	BYTE byDiskNumber[MAX_DISKNUM_V30];/*When dwAlarmType is 1,4 or 5, it stands for Hard Disk, dwDiskNumber[0] is the first disk*/
}NET_DVR_ALARMINFO_V30, *LPNET_DVR_ALARMINFO_V30;

typedef struct 
{
	DWORD dwAlarmType;/*0-sensor alarm;1-hard disk full;2-video lost;3-motion detection;4-hard disk unformatted;5-hard disk error;6-tampering detection;7-unmatched video output standard;8-illegal operation;9-serial port status;0xa-GPS information(for mobile DVR)*/
	DWORD dwAlarmInputNumber;/*/*Alarm input Port, When the dwAlarmType is 9, it stands for states of Serail port, 0-normal, -1-error*/
	DWORD dwAlarmOutputNumber[MAX_ALARMOUT];/*State of Alarm output channel1--Triggered*/
	DWORD dwAlarmRelateChannel[MAX_CHANNUM];/*channels triggered to record1-recording, dwAlarmRelateChannel[0] is the first channel*/
	DWORD dwChannel[MAX_CHANNUM];/*If the dwAlarmType is 2,3 or 6it stands for channeldwChannel[0] is the first channel*/
	DWORD dwDiskNumber[MAX_DISKNUM];/*When dwAlarmType is 1,4 or 5, it stands for Hard Disk, dwDiskNumber[0] is the first disk*/
}NET_DVR_ALARMINFO, *LPNET_DVR_ALARMINFO;




//////////////////////////////////////////////////////////////////////////////////////
//IP Camera Parameter
/* IP Device */
typedef struct 
{
    DWORD dwEnable;				    /* Enable this device */
    BYTE sUserName[NAME_LEN];		/* Username */
    BYTE sPassword[PASSWD_LEN];	    /* Password */ 
    NET_DVR_IPADDR struIP;			/* IP address */
    WORD wDVRPort;			 	    /* Port */
    BYTE byRes[34];					/* Reserved */
}NET_DVR_IPDEVINFO, *LPNET_DVR_IPDEVINFO;

/* IP Channel parameters */
typedef struct 
{
    BYTE byEnable;					/* 0-Failed to connect IP device1-Successfully*/
    BYTE byIPID;					/* ID of IP device, the range: 1 to MAX_IP_DEVICE */
    BYTE byChannel;					/* Channel No. */
    BYTE byRes[33];					/* Reserved */
} NET_DVR_IPCHANINFO, *LPNET_DVR_IPCHANINFO;

/* Struct of connecting IP device*/
typedef struct 
{
    DWORD dwSize;			                            /* Struct Size */
    NET_DVR_IPDEVINFO  struIPDevInfo[MAX_IP_DEVICE];    /* IP Device */
    BYTE byAnalogChanEnable[MAX_ANALOG_CHANNUM];        /* Enable analog channel or notchannel 1(low bit) to channel 32(high bit)0-invalid; 1-valid */
    NET_DVR_IPCHANINFO struIPChanInfo[MAX_IP_CHANNEL];	/* IP Channel */    
}NET_DVR_IPPARACFG, *LPNET_DVR_IPPARACFG;

/* Alarm output channel */
typedef struct 
{
    BYTE byIPID;					/* ID of IP device, the range: 1 to MAX_IP_DEVICE */
    BYTE byAlarmOut;				/* Alarm output NO. */
    BYTE byRes[18];					/* Reserved */
}NET_DVR_IPALARMOUTINFO, *LPNET_DVR_IPALARMOUTINFO;

/* IP Alarm output configuration */
typedef struct 
{
    DWORD dwSize;												/*struct size */    
	NET_DVR_IPALARMOUTINFO struIPAlarmOutInfo[MAX_IP_ALARMOUT];	/* IP alarm output */
}NET_DVR_IPALARMOUTCFG, *LPNET_DVR_IPALARMOUTCFG;

/* Alarm input parameters */
typedef struct 
{
    BYTE byIPID;					/* ID of IP device, the range: 1 to MAX_IP_DEVICE */
    BYTE byAlarmIn;					/* Alarm input NO. */
    BYTE byRes[18];					/* Reserved */
}NET_DVR_IPALARMININFO, *LPNET_DVR_IPALARMININFO;

/* IP Alarm input configuration */
typedef struct 
{
    DWORD dwSize;											 /*struct size */  				  
    NET_DVR_IPALARMININFO struIPAlarmInInfo[MAX_IP_ALARMIN]; /* IP alarm input */
}NET_DVR_IPALARMINCFG, *LPNET_DVR_IPALARMINCFG;

//IP Camera alarm info
typedef struct 
{
    NET_DVR_IPDEVINFO  struIPDevInfo[MAX_IP_DEVICE];            /* IP Device */
    BYTE byAnalogChanEnable[MAX_ANALOG_CHANNUM];                /* Enable analog channel or not0-Enable; 1-Disable */
    NET_DVR_IPCHANINFO struIPChanInfo[MAX_IP_CHANNEL];	        /* IP Channel */
    NET_DVR_IPALARMININFO struIPAlarmInInfo[MAX_IP_ALARMIN];    /* IP Alarm input */
    NET_DVR_IPALARMOUTINFO struIPAlarmOutInfo[MAX_IP_ALARMOUT]; /* IP Alarm output */
}NET_DVR_IPALARMINFO, *LPNET_DVR_IPALARMINFO;
//Configuration of local Hard Disk
typedef struct
{
    DWORD dwHDNo;         /*Hard Disk No. (0~MAX_DISKNUM_V30-1) */
    DWORD dwCapacity;     /*Capacity(Read only)*/
    DWORD dwFreeSpace;    /*Free space(Read only)*/
    DWORD dwHdStatus;     /*Disk status(Read only) 0-Normal, 1-Raw, 2-Error, 3-SMART State, 4-Unmatched, 5-Sleep*/
    BYTE  byHDAttr;       /*0-Defaulty, 1-Redundancy; 2-Read only*/
    BYTE  byRes1[3];
    DWORD dwHdGroup;      /*Disk Group (1-MAX_HD_GROUP)*/
    BYTE  byRes2[120];
}NET_DVR_SINGLE_HD, *LPNET_DVR_SINGLE_HD;

typedef struct
{
    DWORD dwSize;
    DWORD dwHDCount;          /*Number of Disk(Read only)*/
    NET_DVR_SINGLE_HD struHDInfo[MAX_DISKNUM_V30];//Reboot Device to take effect
}NET_DVR_HDCFG, *LPNET_DVR_HDCFG;

//Local Disk Group Configuration
typedef struct
{
    DWORD dwHDGroupNo;       /*Group NO.(Read only) 1-MAX_HD_GROUP*/        
    BYTE byHDGroupChans[64]; /*Corresponding Channel of HD Group, 0-Not record in this group1-Record in this group*/
    BYTE byRes[8];
}NET_DVR_SINGLE_HDGROUP, *LPNET_DVR_SINGLE_HDGROUP;

typedef struct
{
    DWORD dwSize;
    DWORD dwHDGroupCount;        /*Total groups(Read only)*/
    NET_DVR_SINGLE_HDGROUP struHDGroupAttr[MAX_HD_GROUP];//Reboot Device to take effect
}NET_DVR_HDGROUP_CFG, *LPNET_DVR_HDGROUP_CFG;
                                       

//Display Scale Configuration
typedef struct
{
    DWORD dwSize;
    DWORD dwMajorScale;    /* Main Screen  0-No Scale1-Scale*/
    DWORD dwMinorScale;    /* AUX Screen   0-No Scale1-Scale*/
    DWORD dwRes[2];
}NET_DVR_SCALECFG, *LPNET_DVR_SCALECFG;



//DVR Alarm output(9000 extended)
typedef struct 
{
	DWORD dwSize;
	BYTE sAlarmOutName[NAME_LEN];	/* Name */
	DWORD dwAlarmOutDelay;			/* Alarm Duration(-1--Stop manually) */
	//0-5 Sec,1-10Sec,2-30Sec,3-1Min,4-2Min,5-5Min,6-10Min,7-Stop Manually
	NET_DVR_SCHEDTIME struAlarmOutTime[MAX_DAYS][MAX_TIMESEGMENT_V30];/* Time Segment for Alarm output */
    BYTE byRes[16];
}NET_DVR_ALARMOUTCFG_V30, *LPNET_DVR_ALARMOUTCFG_V30;

//DVR Alarm output
typedef struct 
{
	DWORD dwSize;
	BYTE sAlarmOutName[NAME_LEN];	/* Name */
	DWORD dwAlarmOutDelay;	/* Alarm Duration(-1--Stop manually) */
	//0-5Sec,1-10Sec,2-30Sec,3-1Min,4-2Min,5-5Min,6-10Min,7-Stop Manually
	NET_DVR_SCHEDTIME struAlarmOutTime[MAX_DAYS][MAX_TIMESEGMENT]; /* Time Segment for Alarm output */
}NET_DVR_ALARMOUTCFG, *LPNET_DVR_ALARMOUTCFG;

//DVR Local Preview(9000 extended)
typedef struct 
{
    DWORD dwSize;
    BYTE byPreviewNumber;//Number of preview channels,0-1 window,1-4 windows,2-9 windows,3-16 windows,0xff: largest
    BYTE byEnableAudio;//Preview audio,0-No,1-Yes
    WORD wSwitchTime;//duration to switch,0-disable,1-5s,2-10s,3-20s,4-30s,5-60s,6-120s,7-300s
    BYTE bySwitchSeq[MAX_PREVIEW_MODE][MAX_WINDOW_V30];//Order to switch, lSwitchSeq[i]==0xff-not used
    BYTE byRes[24];
}NET_DVR_PREVIEWCFG_V30, *LPNET_DVR_PREVIEWCFG_V30;
//DVR Local Preview 
typedef struct 
{
	DWORD dwSize;
	BYTE byPreviewNumber;//Number of preview channels,0-1 window,1-4 windows,2-9 windows,3-16 windows,0xff: largest
	BYTE byEnableAudio;//Preview audio,0-No,1-Yes
	WORD wSwitchTime;//duration to switch,0-disable,1-5s,2-10s,3-20s,4-30s,5-60s,6-120s,7-300s
	BYTE bySwitchSeq[MAX_WINDOW];//Order to switch, lSwitchSeq[i] 0xff-not used
}NET_DVR_PREVIEWCFG, *LPNET_DVR_PREVIEWCFG;

//DVR video output
typedef struct 
{
	WORD wResolution;							/* Resolution */
	WORD wFreq;									/* Refresh rate */
	DWORD dwBrightness;							/* Brightness */
}NET_DVR_VGAPARA;

/*
* MATRIX Output Configuration
*/
typedef struct
{		
	WORD	wOrder[MAX_ANALOG_CHANNUM];		/* Preview order, 0xff means this channel is disabled */
	WORD	wSwitchTime;					/* Time to witch */
	BYTE	res[14];
}NET_DVR_MATRIXPARA_V30, *LPNET_DVR_MATRIXPARA_V30;

typedef struct 
{
	WORD wDisplayLogo;						/* Display Channel No. */
	WORD wDisplayOsd;						/* Display Time */
}NET_DVR_MATRIXPARA;

typedef struct 
{
	BYTE byVideoFormat;						/* Video Standard,0-PAL,1-NTSC */
	BYTE byMenuAlphaValue;					/* the contrast between Menu and background image */
	WORD wScreenSaveTime;					/* Screen Saver 0-Never,1-1Min,2-2Min,3-5Min,4-10Min,5-20Min,6-30Min */
	WORD wVOffset;							/* Offset of video output */
	WORD wBrightness;						/* Brightness*/
	BYTE byStartMode;						/* Video output mode(0:Menu,1:Preview)*/
	BYTE byEnableScaler;                    /* Enable Scale (0-Disable, 1-Enable)*/
}NET_DVR_VOOUT;

//DVR Video output (9000 extended)
typedef struct 
{
	DWORD dwSize;
	NET_DVR_VOOUT struVOOut[MAX_VIDEOOUT_V30];
	NET_DVR_VGAPARA struVGAPara[MAX_VGA_V30];					/* VGA Parameter */
	NET_DVR_MATRIXPARA_V30 struMatrixPara[MAX_MATRIXOUT];		/* MATRIX Parameter */
    BYTE byRes[16];
}NET_DVR_VIDEOOUT_V30, *LPNET_DVR_VIDEOOUT_V30;

//DVR Video Output
typedef struct 
{
	DWORD dwSize;
	NET_DVR_VOOUT struVOOut[MAX_VIDEOOUT];
	NET_DVR_VGAPARA struVGAPara[MAX_VGA];	/* VGA Parameter */
	NET_DVR_MATRIXPARA struMatrixPara;		/* MATRIX Parameter */
}NET_DVR_VIDEOOUT, *LPNET_DVR_VIDEOOUT;

//Single User Parameters(Sub Struct)(9000 extended)
typedef struct
{
	BYTE sUserName[NAME_LEN];		/* Username */
	BYTE sPassword[PASSWD_LEN];		/* Password */
	BYTE byLocalRight[MAX_RIGHT];	/* Local privilege */
	/*   
	array 0: local PTZ control
    array 1: local manual record
	array 2: local playback
    array 3: local configuration 
	array 4: local log & status query 
    array 5: local advanced settings (upgrade, format, reboot, shut down)
    array 6: local parameter check
    array 7: local analog & IP camera management 
    array 8: local backup
    array 9: local shut down/reboot
	*/

	BYTE byRemoteRight[MAX_RIGHT];/* remote privilege settings */
	/* 
       array 0: remote PTZ control
       array 1: remote manual record
       array 2: remote playback
       array 3: remote configuration 
       array 4: remote log & status query
       array 5: remote advanced settings (upgrade, format, reboot, shut down)
       array 6: remote start voice talk
       array 7: remote preview
	   array 8-remote alarm upload to center, alarm output
       array 9-remote control local output
       array 10-remote serial port control
       array 11: remote parameter query
       array 12: remote analog & IP camera management
       array 13: remote shut down/reboot
	*/
	BYTE byNetPreviewRight[MAX_CHANNUM_V30];		/* remote preview channel , 0-enable, 1-disable*/
	BYTE byLocalPlaybackRight[MAX_CHANNUM_V30];		/* local playback channel , 0-enable, 1-disable*/
	BYTE byNetPlaybackRight[MAX_CHANNUM_V30];		/* remote playback channel , 0-enable, 1-disable*/
	BYTE byLocalRecordRight[MAX_CHANNUM_V30];		/* local record channel , 0-enable, 1-disable*/
	BYTE byNetRecordRight[MAX_CHANNUM_V30];		/* remote record channel , 0-enable, 1-disable*/
	BYTE byLocalPTZRight[MAX_CHANNUM_V30];		/* local PTZ channel , 0-enable, 1-disable*/
	BYTE byNetPTZRight[MAX_CHANNUM_V30];			/* remote PTZ channel , 0-enable, 1-disable*/
	BYTE byLocalBackupRight[MAX_CHANNUM_V30];		/* local backup channel , 0-enable, 1-disable*/
	NET_DVR_IPADDR struUserIP;		/* User IP (0 stands for no IP restriction) */
	BYTE byMACAddr[MACADDR_LEN];	/* MAC */
	BYTE byPriority;				/* Prioroty settings , 0xff- disable , 0-low, 1-Mid, 2-High */
     /*
     LowDefault privileges including local/remote playback, log & status query, reboot/shut down.
	 MidInclude local/remote PTZ control, manual record, voice talk, playback, log & status query, reboot/shut down, log backup and remote preview. 
	 HighAdministrator
     */
	BYTE byRes[17];	
}NET_DVR_USER_INFO_V30, *LPNET_DVR_USER_INFO_V30;

//Single User Parameters(SDK_V15extended)(Sub Struct)
typedef struct 
{
	BYTE sUserName[NAME_LEN];		/* Username */
	BYTE sPassword[PASSWD_LEN];		/* Password */
	DWORD dwLocalRight[MAX_RIGHT];	/* privilege */
	/*
	array 0-local PTZ control
	array 1-local manual record
	array 2-local playback
	array 3-local configuration
	array 4-local log & status query
	array 5-local advanced settings (upgrade, format, reboot, shut down)
	*/
	DWORD dwLocalPlaybackRight;		/*  local playback channel. 1 bit0 -- channel 1*/
	DWORD dwRemoteRight[MAX_RIGHT];	/* privilege */
	/*
	array 0-remote  PTZ control
	array 1-remote manual record
	array 2-remote playback
	array 3-remote configuration
	array 4-remote log & status query
	array 5-remote advanced settings (upgrade, format, reboot, shut down)
	array 6-remote start voice talk
	array 7-remote preview
	array 8-remote alarm upload to center, alarm output
	array 9-remote control local output
	array 10-remote serial port control
	*/
	DWORD dwNetPreviewRight;		/* remote preview channel number, bit0 -- channel 1*/
	DWORD dwNetPlaybackRight;		/* remote playback channel number, bit0 -- channel 1*/
	char sUserIP[16];				/* User IP (0 stands for no IP restriction) */
	BYTE byMACAddr[MACADDR_LEN];	/* MAC */
}NET_DVR_USER_INFO_EX, *LPNET_DVR_USER_INFO_EX;

//Single User Parameters(Sub Struct)
typedef struct 
{
	BYTE sUserName[NAME_LEN];		/* Username */
	BYTE sPassword[PASSWD_LEN];		/* Password */
	DWORD dwLocalRight[MAX_RIGHT];	/* privilege */
	/*
	array 0-local PTZ control
	array 1-local manual record
	array 2-local playback
	array 3-local configuration
	array 4-local log & status query
	array 5-local advanced settings (upgrade, format, reboot, shut down)
	*/
	DWORD dwRemoteRight[MAX_RIGHT];	/* privilege */
	/*
	array 0-remote  PTZ control
	array 1-remote manual record
	array 2-remote playback
	array 3-remote configuration
	array 4-remote log & status query
	array 5-remote advanced settings (upgrade, format, reboot, shut down)
	array 6-remote start voice talk
	array 7-remote preview
	array 8-remote alarm upload to center, alarm output
	array 9-remote control local output
	array 10-remote serial port control
	*/
	char sUserIP[16];				/* User IP (0 stands for no IP restriction) */
	BYTE byMACAddr[MACADDR_LEN];	/* MAC */
}NET_DVR_USER_INFO, *LPNET_DVR_USER_INFO;


//DVR User Parameters(9000extended)
typedef struct
{
	DWORD dwSize;
	NET_DVR_USER_INFO_V30 struUser[MAX_USERNUM_V30];
}NET_DVR_USER_V30, *LPNET_DVR_USER_V30;

//DVR User Parameters(SDK_V15extended)
typedef struct 
{
	DWORD dwSize;
	NET_DVR_USER_INFO_EX struUser[MAX_USERNUM];
}NET_DVR_USER_EX, *LPNET_DVR_USER_EX;

//DVR User Parameters
typedef struct 
{
	DWORD dwSize;
	NET_DVR_USER_INFO struUser[MAX_USERNUM];
}NET_DVR_USER, *LPNET_DVR_USER;

//DVR Exception Parameters(9000extended)
typedef struct 
{
	DWORD dwSize;
	NET_DVR_HANDLEEXCEPTION_V30 struExceptionHandleType[MAX_EXCEPTIONNUM_V30];
	/*array 0- hard disk is full, 1- hard disk error, 2- signal lost, 3- network link is broken, 4-illegal access, 5- input/output video standard not match*/
}NET_DVR_EXCEPTION_V30, *LPNET_DVR_EXCEPTION_V30;

//DVR Exception Parameters
typedef struct 
{
	DWORD dwSize;
	NET_DVR_HANDLEEXCEPTION struExceptionHandleType[MAX_EXCEPTIONNUM];
	/*array 0- hard disk is full, 1- hard disk error, 2- signal lost, 3- network link is broken, 4-illegal access, 5- input/output video standard not match, 6-video in exception*/
}NET_DVR_EXCEPTION, *LPNET_DVR_EXCEPTION;

//Channel State(9000 extended)
typedef struct 
{
	BYTE byRecordStatic; //whether the channel is in recording, 0- no, 1- yes
	BYTE bySignalStatic; //video signal status, 0- normal, 1- lost
	BYTE byHardwareStatic;//the channel hardware status, 0- normal, 1- abnormal, e.g. DSP is not work
	BYTE byRes1;		//Reserved
	DWORD dwBitRate;	//actual bit rate
	DWORD dwLinkNum;	//connected client number
	NET_DVR_IPADDR struClientIP[MAX_LINK];//client IP referred to NET_DVR_IPADDR
    DWORD dwIPLinkNum;//if the current channel is set as IPC channel, then this parameter represents the current connected IP channel number.
	BYTE byRes[12];
}NET_DVR_CHANNELSTATE_V30, *LPNET_DVR_CHANNELSTATE_V30;

//Channel State
typedef struct 
{
	BYTE byRecordStatic; //whether the channel is in recording, 0- no, 1- yes
	BYTE bySignalStatic; //video signal status, 0- normal, 1- lost
	BYTE byHardwareStatic;//the channel hardware status, 0- normal, 1- abnormal, e.g. DSP is not work
	char reservedData;		//Reserved
	DWORD dwBitRate;	//actual bit rate
	DWORD dwLinkNum;	//connected client number
	DWORD dwClientIP[MAX_LINK];//client IP
}NET_DVR_CHANNELSTATE, *LPNET_DVR_CHANNELSTATE;

//Hard Disk Status
typedef struct 
{
	DWORD dwVolume;//Capacity
	DWORD dwFreeSpace;//Free Space
	DWORD dwHardDiskStatic; //HD status0-active;1-sleep mode;2-abnormal; 3- sleep mode error
}NET_DVR_DISKSTATE, *LPNET_DVR_DISKSTATE;

//DVR Work State(9000 extended)
typedef struct 
{
	DWORD dwDeviceStatic; 	//the devices status, 0- normal, 1- the occupancy of CPU is too high, more than 85%, 2-hardware error, e.g. the serial ports do not work
	NET_DVR_DISKSTATE  struHardDiskStatic[MAX_DISKNUM_V30]; 
	NET_DVR_CHANNELSTATE_V30 struChanStatic[MAX_CHANNUM_V30];//channel status  as NET_DVR_CHANNELSTATE
	BYTE  byAlarmInStatic[MAX_ALARMIN_V30]; //alarm input status, 0- no alarm, 1-alarm
	BYTE  byAlarmOutStatic[MAX_ALARMOUT_V30]; //alarm output status, 0-no output, 1-alarm output
	DWORD  dwLocalDisplay;//Local display status, 0- normal, 1-abnormal
    BYTE  byAudioChanStatus[MAX_AUDIO_V30];//Audio channel status, 0-unused; 1-on using0xff-invalid
    BYTE  byRes[10];
}NET_DVR_WORKSTATE_V30, *LPNET_DVR_WORKSTATE_V30;

//DVR Status Structure 
typedef struct 
{
	DWORD dwDeviceStatic; 	//the devices status, 0- normal, 1- the occupancy of CPU is too high, more than 85%, 2-hardware error, e.g. the serial ports do not work
	NET_DVR_DISKSTATE  struHardDiskStatic[MAX_DISKNUM];
	NET_DVR_CHANNELSTATE struChanStatic[MAX_CHANNUM];//channel status  as NET_DVR_CHANNELSTATE
	BYTE  byAlarmInStatic[MAX_ALARMIN];			//alarm input status, 0- no alarm, 1-alarm
	BYTE  byAlarmOutStatic[MAX_ALARMOUT];		//alarm output status, 0-no output, 1-alarm output
	DWORD  dwLocalDisplay;						//Local display status, 0- normal, 1-abnormal
}NET_DVR_WORKSTATE, *LPNET_DVR_WORKSTATE;

/************************DVR Log begin***************************/

/* Alarm */
//Main Type
#define MAJOR_ALARM					0x1
//Hypo-Type
#define MINOR_ALARM_IN					0x1  /* alarm input */
#define MINOR_ALARM_OUT					0x2  /* alarm output*/
#define MINOR_MOTDET_START				0x3  /*	motion detection alarm start */
#define MINOR_MOTDET_STOP				0x4  /* motion detection alarm stop*/
#define MINOR_HIDE_ALARM_START			0x5  /* mask alarm start */
#define MINOR_HIDE_ALARM_STOP			0x6  /* mask alarm stop */

/*Exception */
//Main Type
#define MAJOR_EXCEPTION				0x2
//Hypo-Type
#define MINOR_VI_LOST					0x21 /* Video loss */
#define MINOR_ILLEGAL_ACCESS			0x22 /* Illegal access */
#define MINOR_HD_FULL					0x23 /* HD full */
#define MINOR_HD_ERROR					0x24 /* HD error */
#define MINOR_DCD_LOST					0x25 /* MODEM  off-line(Reserved) */
#define MINOR_IP_CONFLICT				0x26 /* IP conflict */
#define MINOR_NET_BROKEN				0x27 /* Network disconnected */
#define MINOR_REC_ERROR                 0x28 /* Record error */
#define MINOR_IPC_NO_LINK               0x29 /* IPC connection failed */
#define MINOR_VI_EXCEPTION              0x2a /* Video input error (for analog channel only)
 */


/* Operation */
//Main Type
#define MAJOR_OPERATION				0x3
//Hypo-Type
#define MINOR_START_DVR					0x41 /* Power On */
#define MINOR_STOP_DVR					0x42 /* Power off */
#define MINOR_STOP_ABNORMAL				0x43 /* Illegal shut down */
#define MINOR_REBOOT_DVR                0x44    /*Local reboot DVR*/

#define MINOR_LOCAL_LOGIN				0x50 /* Login (local) */
#define MINOR_LOCAL_LOGOUT				0x51 /* Logout (local)*/
#define MINOR_LOCAL_CFG_PARM			0x52 /* Configuration (local) */
#define MINOR_LOCAL_PLAYBYFILE			0x53 /* Playback (local) */
#define MINOR_LOCAL_PLAYBYTIME			0x54 /* Playback or downlaod by time (local)*/
#define MINOR_LOCAL_START_REC			0x55 /* Start record (local) */
#define MINOR_LOCAL_STOP_REC			0x56 /* Stop record (local)*/
#define MINOR_LOCAL_PTZCTRL				0x57 /* PTZ control (local) */
#define MINOR_LOCAL_PREVIEW				0x58 /* Preview (local)(Reserved)*/
#define MINOR_LOCAL_MODIFY_TIME         0x59 /* Change time (local)(Reserved) */
#define MINOR_LOCAL_UPGRADE				0x5a /* Upgrade (local) */
#define MINOR_LOCAL_RECFILE_OUTPUT      0x5b    /* Backup (local) */
#define MINOR_LOCAL_FORMAT_HDD          0x5c    /* HD format(local) */
#define MINOR_LOCAL_CFGFILE_OUTPUT      0x5d    /* Export Configuration (local) */
#define MINOR_LOCAL_CFGFILE_INPUT       0x5e    /* Import Configuration (local) */
#define MINOR_LOCAL_COPYFILE            0x5f    /* Backup file (local) */
#define MINOR_LOCAL_LOCKFILE            0x60    /* File lockup (local)Reboot IPC (local) */
#define MINOR_LOCAL_UNLOCKFILE          0x61    /* File unlock (local) */
#define MINOR_LOCAL_DVR_ALARM           0x62    /* Clear/Trigger Alarm (Local)*/
#define MINOR_IPC_ADD                   0x63    /* Add IPC (local) */
#define MINOR_IPC_DEL                   0x64    /* Delete IPC (local)*/
#define MINOR_IPC_SET                   0x65    /* Set IPC (local) */
#define MINOR_LOCAL_START_BACKUP		0x66	/* local start backup file */
#define MINOR_LOCAL_STOP_BACKUP			0x67	/* local stop backup file*/
#define MINOR_LOCAL_COPYFILE_START_TIME 0x68	/* local backup:file start time*/
#define MINOR_LOCAL_COPYFILE_END_TIME	0x69	/* local backup:file end time*/

#define MINOR_REMOTE_LOGIN				0x70 /* Login (remote)*/
#define MINOR_REMOTE_LOGOUT				0x71 /* Logout  (remote) */
#define MINOR_REMOTE_START_REC			0x72 /* Start record (remote)*/
#define MINOR_REMOTE_STOP_REC			0x73 /* Stop record  (remote) */
#define MINOR_START_TRANS_CHAN			0x74 /* Start transparent channel (remote) */
#define MINOR_STOP_TRANS_CHAN			0x75 /* Stop transparent channel (remote) */
#define MINOR_REMOTE_GET_PARM			0x76 /* Get parameter (remote)*/
#define MINOR_REMOTE_CFG_PARM			0x77 /* configuration (remote)*/
#define MINOR_REMOTE_GET_STATUS         0x78 /* Get status (remote) */
#define MINOR_REMOTE_ARM				0x79 /* On guard  (remote) */
#define MINOR_REMOTE_DISARM				0x7a /* Disarm  (remote) */
#define MINOR_REMOTE_REBOOT				0x7b /* Reboot  (remote) */
#define MINOR_START_VT					0x7c /* Start voice talk */
#define MINOR_STOP_VT					0x7d /* Stop voice talk */
#define MINOR_REMOTE_UPGRADE			0x7e /* upgrade (remote) */
#define MINOR_REMOTE_PLAYBYFILE         0x7f /* Playback by file name (remote) */
#define MINOR_REMOTE_PLAYBYTIME         0x80 /* Playback by time (remote) */
#define MINOR_REMOTE_PTZCTRL			0x81 /* PTZ control (remote) */
#define MINOR_REMOTE_FORMAT_HDD         0x82 /*Format hard disk(remote) */
#define MINOR_REMOTE_STOP               0x83 /*Shut Down (remote) */
#define MINOR_REMOTE_LOCKFILE			0x84 /* File lockup (remote) */
#define MINOR_REMOTE_UNLOCKFILE         0x85 /* File unlock (remote */
#define MINOR_REMOTE_CFGFILE_OUTPUT     0x86 /* Export Configuration  (remote) */
#define MINOR_REMOTE_CFGFILE_INTPUT     0x87 /* Import Configuration (remote) */
#define MINOR_REMOTE_RECFILE_OUTPUT     0x88 /* Backup recording files (remote) */
#define MINOR_REMOTE_DVR_ALARM          0x89 /* Trigger/clear alarm (remote)*/
#define MINOR_REMOTE_IPC_ADD			0x8a /* Add IPC (remote)*/
#define MINOR_REMOTE_IPC_DEL			0x8b /* Delete IPC (remote)*/
#define MINOR_REMOTE_IPC_SET			0x8c /*Set  IPC (remote)*/


/*Additional Log Info*/
//Main Type
#define MAJOR_INFORMATION			0x4     /*Extra Info*/
//Hypo-Type
#define MINOR_HDD_INFO                  0xa1 /*HD info*/
#define MINOR_SMART_INFO                0xa2 /*SMART info*/
#define MINOR_REC_START                 0xa3 /*Start record*/
#define MINOR_REC_STOP                  0xa4 /*Stop record */
#define MINOR_REC_OVERDUE				0xa5 /*Record overdue*/

/*
If the main type of the log is MAJOR_OPERATION=03(Operation)And Sub type is
MINOR_LOCAL_CFG_PARM=0x52(local configuration)
MINOR_REMOTE_GET_PARM=0x76(remote get configuration)
MINOR_REMOTE_CFG_PARM=0x77(remote set configuration)
dwParaType: is valid, and the relative definition is listed as below:
*/
#define PARA_VIDEOOUT 0x1
#define PARA_IMAGE  0x2
#define PARA_ENCODE  0x4
#define PARA_NETWORK 0x8
#define PARA_ALARM  0x10
#define PARA_EXCEPTION 0x20
#define PARA_DECODER 0x40    /*Decoder*/
#define PARA_RS232  0x80
#define PARA_PREVIEW 0x100
#define PARA_SECURITY 0x200
#define PARA_DATETIME 0x400
#define PARA_FRAMETYPE 0x800    /*Frame Type*/

//Log Info(9000extended)
typedef struct 
{
	NET_DVR_TIME strLogTime;
	DWORD	dwMajorType;	//Main type 1-alarm; 2-abnormal; 3-operation; 0xff-all 
	DWORD	dwMinorType;	//Hypo-Type 0-all;
	BYTE	sPanelUser[MAX_NAMELEN]; //user ID for local panel operation
	BYTE	sNetUser[MAX_NAMELEN];//user ID for network operation
	NET_DVR_IPADDR	struRemoteHostAddr;//remote host IP
	DWORD	dwParaType;//parameter type
	DWORD	dwChannel;//channel number
	DWORD	dwDiskNumber;//HD number
	DWORD	dwAlarmInPort;//alarm input port
	DWORD	dwAlarmOutPort;//alarm output port
    DWORD   dwInfoLen;
    char    sInfo[LOG_INFO_LEN];
}NET_DVR_LOG_V30, *LPNET_DVR_LOG_V30;

//Log Info
typedef struct 
{
	NET_DVR_TIME strLogTime;
	DWORD	dwMajorType;	//MMain type 1-alarm; 2-abnormal; 3-operation; 0xff-all 
	DWORD	dwMinorType;//Hypo-Type 0-all;
	BYTE	sPanelUser[MAX_NAMELEN]; //user ID for local panel operation
	BYTE	sNetUser[MAX_NAMELEN];//user ID for network operation
	char	sRemoteHostAddr[16];//remote host IP
	DWORD	dwParaType;//parameter type
	DWORD	dwChannel;//channel number
	DWORD	dwDiskNumber;//HD number
	DWORD	dwAlarmInPort;//alarm input port
	DWORD	dwAlarmOutPort;//alarm output port
}NET_DVR_LOG, *LPNET_DVR_LOG;

/************************DVR Log end***************************/


//Alarm output state(9000 extended)
typedef struct 
{
	BYTE Output[MAX_ALARMOUT_V30];
}NET_DVR_ALARMOUTSTATUS_V30, *LPNET_DVR_ALARMOUTSTATUS_V30;

//Alarm output state
typedef struct 
{
	BYTE Output[MAX_ALARMOUT];
}NET_DVR_ALARMOUTSTATUS, *LPNET_DVR_ALARMOUTSTATUS;

//Transaction Info
typedef struct 
{
	USHORT m_Year;
	USHORT m_Month;
	USHORT m_Day;
	USHORT m_Hour;
	USHORT m_Minute;
	USHORT m_Second;
	BYTE DeviceName[24];	//Device name
	DWORD dwChannelNumer;	//Channel name
	BYTE CardNumber[32];	//Credit Card No.
	char cTradeType[12];	//Transaction type	
	DWORD dwCash;			//Transaction money 
}NET_DVR_TRADEINFO, *LPNET_DVR_TRADEINFO;


//Special for ATM
/****************************ATM(begin)***************************/
#define NCR		0
#define DIEBOLD	1
#define WINCOR_NIXDORF	2
#define SIEMENS	3
#define OLIVETTI	4
#define FUJITSU	5
#define HITACHI	6
#define SMI		7
#define IBM		8
#define BULL	9
#define YiHua	10
#define LiDe	11
#define GDYT	12
#define Mini_Banl	13
#define GuangLi	14
#define DongXin	15
#define ChenTong	16
#define NanTian	17
#define XiaoXing	18
#define GZYY	19
#define QHTLT	20
#define DRS918	21
#define KALATEL	22
#define NCR_2	23	
#define NXS		24


/*Frame Type*/
typedef struct 
{
	BYTE code[12];		/* code */
}NET_DVR_FRAMETYPECODE;

//ATM Parameters (9000extended)
typedef struct
{
	DWORD	dwSize;
	NET_DVR_IPADDR	struATMIP;               	/* ATM IP Address */
	DWORD	dwATMType;							/* ATM Type */
	DWORD	dwInputMode;						/* 0- network listening 1-network receive 2- directly input via serial port 3- input ATM command via serial port*/
	DWORD	dwFrameSignBeginPos;				/* the start position of Message flag*/
	DWORD	dwFrameSignLength;					/* the length of Message flag */
	BYTE	byFrameSignContent[12];				/* the content of Message flag */
	DWORD	dwCardLengthInfoBeginPos;			/* offset of credit card No. length information */
	DWORD	dwCardLengthInfoLength;				/* the length of the card length information */
	DWORD	dwCardNumberInfoBeginPos;			/* Start position of the card number information */
	DWORD	dwCardNumberInfoLength;				/* Length of the card number information */
	DWORD	dwBusinessTypeBeginPos;				/* the offset of operation type information */
	DWORD	dwBusinessTypeLength;				/* the length of the operation type */
	NET_DVR_FRAMETYPECODE	frameTypeCode[10];	/* type */
	WORD	wATMPort;							/* Card number capture port number (network protocol mode)  */
	WORD	wProtocolType;						/* network protocol type*/
    BYTE    byRes[24];
}NET_DVR_FRAMEFORMAT_V30, *LPNET_DVR_FRAMEFORMAT_V30;

//ATM Parameters
typedef struct 
{
	DWORD dwSize;
	char sATMIP[16];						/* ATM IP */
	DWORD dwATMType;						/* ATM Type*/
	DWORD	dwInputMode;						/* 0- network listening 1-network receive 2- directly input via serial port 3- input ATM command via serial port*/
	DWORD	dwFrameSignBeginPos;				/* the start position of Message flag*/
	DWORD	dwFrameSignLength;					/* the length of Message flag */
	BYTE	byFrameSignContent[12];				/* the content of Message flag */
	DWORD	dwCardLengthInfoBeginPos;			/* offset of credit card No. length information */
	DWORD	dwCardLengthInfoLength;				/* the length of the card length information */
	DWORD	dwCardNumberInfoBeginPos;			/* Start position of the card number information */
	DWORD	dwCardNumberInfoLength;				/* Length of the card number information */
	DWORD	dwBusinessTypeBeginPos;				/* the offset of operation type information */
	DWORD	dwBusinessTypeLength;				/* the length of the operation type */
	NET_DVR_FRAMETYPECODE	frameTypeCode[10];	/* type */
}NET_DVR_FRAMEFORMAT, *LPNET_DVR_FRAMEFORMAT;


/*****************************DS-6001D/F(begin)***************************/
//DS-6001D Decoder
typedef struct 
{
	BYTE byEncoderIP[16];		//Server IP that decoder connected
	BYTE byEncoderUser[16];		//Server Username that decoder connected
	BYTE byEncoderPasswd[16];	//Server Password that decoder connected
	BYTE bySendMode;			//Server Connection Mode that decoder connected
	BYTE byEncoderChannel;		//Server Channel No. that decoder connected
	WORD wEncoderPort;			//Server Port that decoder connected
	BYTE reservedData[4];		//Reserved
}NET_DVR_DECODERINFO, *LPNET_DVR_DECODERINFO;

typedef struct 
{
	BYTE byEncoderIP[16];		//Server IP that decoder connected
	BYTE byEncoderUser[16];		//Server Username that decoder connected
	BYTE byEncoderPasswd[16];	//Server Password that decoder connected
	BYTE byEncoderChannel;		//Server Channel No. that decoder connected
	BYTE bySendMode;			//Server Connection Mode that decoder connected
	WORD wEncoderPort;			//Server Port that decoder connected
	DWORD dwConnectState;		//Server State that decoder connected
	BYTE reservedData[4];		//Reserved
}NET_DVR_DECODERSTATE, *LPNET_DVR_DECODERSTATE;

/*Definition of Decoder Control Code */
#define NET_DEC_STARTDEC		1
#define NET_DEC_STOPDEC			2
#define NET_DEC_STOPCYCLE		3
#define NET_DEC_CONTINUECYCLE	4

/*Channel Connected Configuration*/
typedef struct 
{
	char sDVRIP[16];				/* DVR IP Address */
	WORD wDVRPort;			 		/* Ports */
	BYTE sUserName[NAME_LEN];		/* Username */
	BYTE sPassword[PASSWD_LEN];		/* Password */
	BYTE byChannel;					/* Channel No. */
	BYTE byLinkMode;				/* Connection Mode */
	BYTE byLinkType;				/* Stream for Connection  0Main Stream 1Sub Stream */
}NET_DVR_DECCHANINFO, *LPNET_DVR_DECCHANINFO;

/*Configuration of Each Decoding Channel*/
typedef struct 
{
	BYTE	byPoolChans;			/*Switch channel number on each decoder channel, range from 0-4*/
	NET_DVR_DECCHANINFO struchanConInfo[MAX_DECPOOLNUM];
	BYTE	byEnablePoll;			/*enable switching or not: 0- disable 1- enable*/
	BYTE	byPoolTime;				/*switching interval: 1-10 sec; 2- 15 sec; 3- 20 sec; 4- 30 sec;  5- 45 sec; 6- 1min; 7- 2min; 8- 5min */
}NET_DVR_DECINFO, *LPNET_DVR_DECINFO;

/*Decoder Configuration*/
typedef struct 
{
	DWORD	dwSize;
	DWORD	dwDecChanNum; 		/*Number of decoding channels*/
	NET_DVR_DECINFO struDecInfo[MAX_DECNUM];
}NET_DVR_DECCFG, *LPNET_DVR_DECCFG;

//2005-08-01
/* Transparent Channel of Decoder */
typedef struct 
{
	DWORD dwEnableTransPort;	/* Enable transparent channel or not: 0- disable; 1- enable*/
	char sDecoderIP[16];		/* DVR IP */
	WORD wDecoderPort;			/* Port number */
	WORD wDVRTransPort;			/* Configuration DVR output serial port: 1- 232; 2- 485 */
	char cReserve[4];
}NET_DVR_PORTINFO, *LPNET_DVR_PORTINFO;

typedef struct 
{
	DWORD dwSize;
	NET_DVR_PORTINFO struTransPortInfo[MAX_TRANSPARENTNUM]; /* Array 0--232; Array 1--485 */
}NET_DVR_PORTCFG, *LPNET_DVR_PORTCFG;

/* Remote Playback */
typedef struct 
{
	DWORD dwSize;
	char sDecoderIP[16];		/* DVR IP*/
	WORD wDecoderPort;			/* Port */
	WORD wLoadMode;				/* Playback Mode 1by name 2by time */
	union
	{
		BYTE byFile[100];		/* File Name */
		struct
		{
			DWORD dwChannel;
			BYTE sUserName[NAME_LEN];	/* Username for playback*/
			BYTE sPassword[PASSWD_LEN];	/* Password */
			NET_DVR_TIME struStartTime;	/* Start time of playback by time mode*/
			NET_DVR_TIME struStopTime;	/* End time */
		}bytime;
	}mode_size;
}NET_DVR_PLAYREMOTEFILE, *LPNET_DVR_PLAYREMOTEFILE;

/*Decoder Channel Status Structure */
typedef struct 
{
	DWORD dwWorkType;		/*Work mode: 1- switching; 2- dynamic connect to decoder; 3- playback by file; 4- playback by time*/
	char sDVRIP[16];		/*Connected device IP*/
	WORD wDVRPort;			/*Connected port number*/
	BYTE byChannel;			/*Channel number */
	BYTE byLinkMode;		/*Connection mode */
	DWORD	dwLinkType;		/*Connection stream type: 0- main stream; 1- sub stream*/
	union
	{
		struct
		{
			BYTE sUserName[NAME_LEN];	/*Username*/
			BYTE sPassword[PASSWD_LEN];	/* Password */
			char cReserve[52];
		}userInfo;
		struct
		{
			BYTE   fileName[100];
		}fileInfo;
		struct
		{
			DWORD	dwChannel;
			BYTE	sUserName[NAME_LEN];	/*Username*/
			BYTE	sPassword[PASSWD_LEN];	/* Password */
			NET_DVR_TIME struStartTime;		/* Start position for playback by time */
			NET_DVR_TIME struStopTime;		/* End position for playback by time */
		}timeInfo;
	}objectInfo;
}NET_DVR_DECCHANSTATUS, *LPNET_DVR_DECCHANSTATUS;

typedef struct 
{
	DWORD   dwSize;
	NET_DVR_DECCHANSTATUS struDecState[MAX_DECNUM];
}NET_DVR_DECSTATUS, *LPNET_DVR_DECSTATUS;
/*****************************DS-6001D/F(end)***************************/

//Single Character Struct (Sub Struct)
typedef struct 
{
	WORD wShowString;				//enable text overlay on preview image: 0-disable; 1-enable. The display area ranges totally 704*576 , with single character size as 32*32
	WORD wStringSize;				/* text length, no more than 44 text character */
	WORD wShowStringTopLeftX;		/* top left X axis position for text overlay*/
	WORD wShowStringTopLeftY;		/* top left Y axis position for text overlay */
	char sString[44];				/* overlay text content*/
}NET_DVR_SHOWSTRINGINFO, *LPNET_DVR_SHOWSTRINGINFO;

//Text Overlay (9000extended)
typedef struct 
{
	DWORD dwSize;
	NET_DVR_SHOWSTRINGINFO struStringInfo[MAX_STRINGNUM_V30];				/* Content for display */
}NET_DVR_SHOWSTRING_V30, *LPNET_DVR_SHOWSTRING_V30;

//Text Overlay extended(8 lines)
typedef struct 
{
	DWORD dwSize;
	NET_DVR_SHOWSTRINGINFO struStringInfo[MAX_STRINGNUM_EX];				/* Content for display  */
}NET_DVR_SHOWSTRING_EX, *LPNET_DVR_SHOWSTRING_EX;

//Text Overlay 
typedef struct 
{
	DWORD dwSize;
	NET_DVR_SHOWSTRINGINFO struStringInfo[MAX_STRINGNUM];				/* Content for display  */
}NET_DVR_SHOWSTRING, *LPNET_DVR_SHOWSTRING;

/****************************DS9000 added Structure(begin)******************************/

/*
EMAIL Parameters Struct
*/
typedef struct
{		
	DWORD		dwSize;
	BYTE		sAccount[NAME_LEN];				/* Email Account*/ 
	BYTE		sPassword[MAX_EMAIL_PWD_LEN];			/*Password */
	struct
	{
		BYTE	sName[NAME_LEN];				/* sender name */
		BYTE	sAddress[MAX_EMAIL_ADDR_LEN];		/* sender address */
	}struSender;
	BYTE		sSmtpServer[MAX_EMAIL_ADDR_LEN];	/* SMTP server */
	BYTE		sPop3Server[MAX_EMAIL_ADDR_LEN];	/* POP3 server */
	struct
	{
		BYTE	sName[NAME_LEN];				/* receiver Name */
		BYTE	sAddress[MAX_EMAIL_ADDR_LEN];		/* receiver address */
	}struReceiver[3];							/* support up to 3 receivers */
	BYTE		byAttachment;					/* with attached snapshot or not */
	BYTE		bySmtpServerVerify;				/* Enable Email server authentication: 1-enable; 0-disable */
    BYTE        byMailInterval;                 /* mail interval */
    BYTE        res[77];
} NET_DVR_EMAILCFG_V30, *LPNET_DVR_EMAILCFG_V30;

/*
DVR Cruise Structure
*/
typedef struct
{	
	DWORD 	dwSize;
	BYTE	byPresetNo[CRUISE_MAX_PRESET_NUMS];		/* Preset No. */
	BYTE 	byCruiseSpeed[CRUISE_MAX_PRESET_NUMS];	/* Cruise Speed */
	WORD	wDwellTime[CRUISE_MAX_PRESET_NUMS];		/* Dwell time */
	BYTE	byEnableThisCruise;						/* Enable this cruise */
	BYTE	res[15];
}NET_DVR_CRUISE_PARA, *LPNET_DVR_CRUISE_PARA; 
/****************************DS9000 Added(end)******************************/


//Time
typedef struct 
{
	DWORD dwMonth;		//Month 0-11 for 1-12 month
	DWORD dwWeekNo;		//Week 0First Week 1Second Week 2Third Week 3Fourth Week 4last Week
	DWORD dwWeekDate;	//Day 0Sun 1Mon 2Tue 3Wed 4Thu 5Fri 6Sat
	DWORD dwHour;		//begin/end hour, begin hour ranges from 0-23, and end hour ranges from 1-23
	DWORD dwMin;		//begin/stop minutes ranges from 0-59
}NET_DVR_TIMEPOINT;

//Time Zone & DST 
typedef struct 
{
	DWORD dwSize;
	BYTE byRes1[16];			//Reserved
	DWORD dwEnableDST;		//enable DST, 0-dsiable; 1-enable
	BYTE byDSTBias;			//DST bias; 30min, 60min, 90min, 120min, count with minute
	BYTE byRes2[3];
	NET_DVR_TIMEPOINT struBeginPoint;	//DST start time
	NET_DVR_TIMEPOINT struEndPoint;		//DST stop time
}NET_DVR_ZONEANDDST, *LPNET_DVR_ZONEANDDST;



//Image Quality
typedef struct 
{
	/*Note: If encoding resolution is VGAit supports grabbing 0=CIF, 1=QCIF, 2=D1 image.
	But if encoding resolution is 3=UXGA(1600x1200), 4=SVGA(800x600), 5=HD720p(1280x720), 6=VGA, 7=XVGA, and 8=HD900p it only support grabbing image with current resolution*/
	WORD	wPicSize;				/* 0=CIF; 1=QCIF; 2=D1; for IPCAM {3=UXGA(1600x1200), 4=SVGA(800x600), 5=HD720p(1280x720),6=VGA, 7=XVGA, 8=HD900p}*/
	WORD	wPicQuality;			/* 0 - the best, 1 - better, 2 - average; */
}NET_DVR_JPEGPARA, *LPNET_DVR_JPEGPARA;

/* aux video out parameter */
//AUX Output Parameter
typedef struct 
{
	DWORD dwSize;
	DWORD dwAlarmOutChan;                       /* 0Cmain video output; 1Caux1 video output; 2Caux2 video output; 3Caux3 video output; 4Caux4 video output*/
	DWORD dwAlarmChanSwitchTime;                /* :1Sec - 10:10Sec */
	DWORD dwAuxSwitchTime[MAX_AUXOUT];			/* aux output switch time0- no switch; 1-5sec2-10sec3-20sec4-30sec5-60sec6-120sec7-300sec*/
	BYTE  byAuxOrder[MAX_AUXOUT][MAX_WINDOW];	/* aux output preview sequence, 0xff means not preview the camera */
}NET_DVR_AUXOUTCFG, *LPNET_DVR_AUXOUTCFG;


//ntp
typedef struct 
{
	BYTE sNTPServer[64];   /* Domain Name or IP addr of NTP server */
	WORD wInterval;		 /* adjust time interval(hours) */
	BYTE byEnableNTP;    /* enable NPT client 0-no1-yes*/
	signed char cTimeDifferenceH; /* Difference with Standard Time (Hour): ranges from -12 ... +13 */
	signed char cTimeDifferenceM;/* Difference with Standard Time (Minute)*/
	BYTE res1;
    WORD wNtpPort;         /* ntp server port(9000 added), 123 is defaulty*/
    BYTE res2[8];
}NET_DVR_NTPPARA, *LPNET_DVR_NTPPARA;

//DDNS
typedef struct 
{
	BYTE sUsername[NAME_LEN];  /* DDNS Username*/								
	BYTE sPassword[PASSWD_LEN];/*Password */
	BYTE sDomainName[64];       /* Domain name */
	BYTE byEnableDDNS;			/*Enable DDNS 0-disable1-enable*/
	BYTE res[15];
}NET_DVR_DDNSPARA, *LPNET_DVR_DDNSPARA;


typedef struct
{
	BYTE byHostIndex;					/* 0-Hikvision DNS(Reserved) 1Dyndns 2PeanutHull 3-xw3322  */
	BYTE byEnableDDNS;					/*enable DDNS: 0-disable; 1-enable*/
	WORD wDDNSPort;						/* DDNS port */
	BYTE sUsername[NAME_LEN];			/* DDNS Username*/
	BYTE sPassword[PASSWD_LEN];			/* DDNS Password */
	BYTE sDomainName[MAX_DOMAIN_NAME];	/* DVR domain name*/
	BYTE sServerName[MAX_DOMAIN_NAME];	/* DDNS server domain name or IP */
	BYTE byRes[16];
}NET_DVR_DDNSPARA_EX, *LPNET_DVR_DDNSPARA_EX;

//9000extended
typedef struct
{
    BYTE byEnableDDNS;
    BYTE byHostIndex;/* 0-Hikvision DNS(Reserved) 1Dyndns 2PeanutHull 3-xw3322 */
    BYTE byRes1[2];
    struct
    {    
        BYTE sUsername[NAME_LEN];			/* DDNS Username*/
        BYTE sPassword[PASSWD_LEN];			/* Password */
        BYTE sDomainName[MAX_DOMAIN_NAME];	/* DVR domain name */
        BYTE sServerName[MAX_DOMAIN_NAME];	/* DDNS server domain name or IP*/
        WORD wDDNSPort;						/* Port */
        BYTE byRes[10];
    } struDDNS[MAX_DDNS_NUMS];
    BYTE byRes2[16];
}NET_DVR_DDNSPARA_V30, *LPNET_DVR_DDNSPARA_V30;

//email
typedef struct 
{
	BYTE sUsername[64];  /* Email Account */
	BYTE sPassword[64];
	BYTE sSmtpServer[64];
	BYTE sPop3Server[64];
	BYTE sMailAddr[64];   /* email */
	BYTE sEventMailAddr1[64];  /* email for upload Alarm/Exception */
	BYTE sEventMailAddr2[64];
	BYTE res[16];
}NET_DVR_EMAILPARA, *LPNET_DVR_EMAILPARA;

//Network Parameter
typedef struct 
{
	DWORD  dwSize;
	char  sDNSIp[16];                /* DNS Server IP */
	NET_DVR_NTPPARA  struNtpClientParam;      /* NTP Parameters */
	NET_DVR_DDNSPARA struDDNSClientParam;     /* DDNS Parameters */
	BYTE res[464];			/* Reserved */
}NET_DVR_NETAPPCFG, *LPNET_DVR_NETAPPCFG;

//nfs Structure Configuration
typedef struct
{
    char sNfsHostIPAddr[16];
    BYTE sNfsDirectory[PATHNAME_LEN];        // PATHNAME_LEN = 128
}NET_DVR_SINGLE_NFS, *LPNET_DVR_SINGLE_NFS;

typedef struct 
{
	DWORD  dwSize;
	NET_DVR_SINGLE_NFS struNfsDiskParam[MAX_NFS_DISK];
}NET_DVR_NFSCFG, *LPNET_DVR_NFSCFG;

//Cruise Point Configuration(for HIK IP Speed Dome)
typedef struct
{
    BYTE	PresetNum;	//Preset
    BYTE	Dwell;		//Dwell time
    BYTE	Speed;		//Speed
    BYTE	Reserve;	//Reserved
}NET_DVR_CRUISE_POINT, *LPNET_DVR_CRUISE_POINT;

typedef struct 
{
	NET_DVR_CRUISE_POINT struCruisePoint[32];			//32 pints in total
}NET_DVR_CRUISE_RET, *LPNET_DVR_CRUISE_RET;

/************************************Multi-Channel Decoder(begin)***************************************/
typedef struct 
{
	DWORD	dwSize;
	char	sFirstDNSIP[16];
	char	sSecondDNSIP[16];
	char	sRes[32];
}NET_DVR_NETCFG_OTHER, *LPNET_DVR_NETCFG_OTHER;

typedef struct 
{
	char 	sDVRIP[16];				/* DVR IP */
	WORD 	wDVRPort;			 	/* Port */
	BYTE 	byChannel;				/* Channel No. */
	BYTE	byTransProtocol;			/* Network Protocol 0-TCP, 1-UDP */
	BYTE	byTransMode;				/* Stream Type 0 - Main Stream 1 - Sub Stream*/
	BYTE	byRes[3];
	BYTE	sUserName[NAME_LEN];			/* DVR login user name */
	BYTE	sPassword[PASSWD_LEN];			/* DVR login Password */
}NET_DVR_MATRIX_DECINFO, *LPNET_DVR_MATRIX_DECINFO;

//Dynamic Decoding
typedef struct 
{
	DWORD	dwSize;				
	NET_DVR_MATRIX_DECINFO struDecChanInfo;		/*Info of Dynamic Decoding Channel*/
}NET_DVR_MATRIX_DYNAMIC_DEC, *LPNET_DVR_MATRIX_DYNAMIC_DEC;

typedef struct  
{
    DWORD 	dwSize;
    DWORD   dwIsLinked;         /* Network link status tag, 0: Sleep, 1: linking, 2: linked, 3: decoding */
    DWORD   dwStreamCpRate;     /* Stream copy rate, X kbits/second */
    char    cRes[64];		/* Reserved */
}NET_DVR_MATRIX_DEC_CHAN_STATUS, *LPNET_DVR_MATRIX_DEC_CHAN_STATUS;

typedef struct 
{
	DWORD	dwSize;
	NET_DVR_MATRIX_DECINFO struDecChanInfo;		/* Decode channel information  */
	DWORD	dwDecState;	/* 0-dynamic decode 1- switch decode 2-playback by time 3-playback by file */
	NET_DVR_TIME StartTime;		/* start time for playback by time mode, */
	NET_DVR_TIME StopTime;		/* stop time for playback by time mode */
	char    sFileName[128];		/* file name for playback by file mode */
}NET_DVR_MATRIX_DEC_CHAN_INFO, *LPNET_DVR_MATRIX_DEC_CHAN_INFO;

//Channel Connected Configuration 2007-11-05
typedef struct 
{
	DWORD dwEnable;					/*0-Disable 1-Enable*/
	NET_DVR_MATRIX_DECINFO struDecChanInfo;		/* Info of switching decoding channel */
}NET_DVR_MATRIX_DECCHANINFO, *LPNET_DVR_MATRIX_DECCHANINFO;

//2007-11-05 Configuration for each channel
typedef struct 
{
	DWORD	dwSize;
	DWORD	dwPoolTime;			/*Switch interval */
	NET_DVR_MATRIX_DECCHANINFO struchanConInfo[MAX_CYCLE_CHAN];
}NET_DVR_MATRIX_LOOP_DECINFO, *LPNET_DVR_MATRIX_LOOP_DECINFO;

//2007-12-22
typedef struct 
{
	BYTE	baudrate; 		/* baud rate */
	BYTE	databits;		/* Data bit */
	BYTE	stopbits;		/* Stop bit*/
	BYTE	parity;			/* Parity digit */
	BYTE	flowcontrol;	/* Flow control */
	BYTE	res[3];
}TTY_CONFIG, *LPTTY_CONFIG;

typedef struct  
{					
	BYTE byTranChanEnable;	/* Open current transparent channel or not 0: close 1: open */	
	/*
		There is a 232 interface and a 485 interface on the decoder, which can all be set as transparent channel, device number can be distributed as below:
		0 - RS485;1 - RS232 Console
	 */
	BYTE	byLocalSerialDevice;			/* Local serial device */
	/*
	 *	Remote output serial device
	 *	1-RS232
	 *	2-RS485
	 */
	BYTE	byRemoteSerialDevice;			/* Remote output serial device */
	BYTE	res1;							/* Reserved */
	char	sRemoteDevIP[16];				/* Remote Device IP */
	WORD	wRemoteDevPort;					/* Remote Net Communication Port */
	BYTE	res2[2];						/* Reserved */
	TTY_CONFIG RemoteSerialDevCfg;
}NET_DVR_MATRIX_TRAN_CHAN_INFO, *LPNET_DVR_MATRIX_TRAN_CHAN_INFO;

typedef struct  
{
	DWORD dwSize;
	BYTE 	by232IsDualChan; /* Set full-duplex 232 transparent channel, set value ranges from 1 to MAX_SERIAL_NUM */
	BYTE	by485IsDualChan; /* Set full-duplex 485 transparent channel, set value ranges from 1 to MAX_SERIAL_NUM */
	BYTE	res[2];	/* Reserved */
	NET_DVR_MATRIX_TRAN_CHAN_INFO struTranInfo[MAX_SERIAL_NUM];/*Support to create transparent channel number up to MAX_SERIAL_NUM*/
}NET_DVR_MATRIX_TRAN_CHAN_CONFIG, *LPNET_DVR_MATRIX_TRAN_CHAN_CONFIG;

//2007-12-24 Merry Christmas Eve...
typedef struct 
{
	DWORD	dwSize;
	char	sDVRIP[16];			/* DVR IP */	
	WORD	wDVRPort;			/* Port */	
	BYTE	byChannel;			/* Channel Port */
	BYTE 	byReserve;
	BYTE	sUserName[NAME_LEN];		/* Username */
	BYTE	sPassword[PASSWD_LEN];		/* Password */
	DWORD	dwPlayMode;   	/* 0-by file 1- by time*/        	
	NET_DVR_TIME StartTime;
	NET_DVR_TIME StopTime;
	char    sFileName[128];
}NET_DVR_MATRIX_DEC_REMOTE_PLAY, *LPNET_DVR_MATRIX_DEC_REMOTE_PLAY;

/* Commands for playing file*/
#define NET_DVR_PLAYSTART		1//Start play
#define NET_DVR_PLAYSTOP		2//Stop play
#define NET_DVR_PLAYPAUSE		3//Pause
#define NET_DVR_PLAYRESTART		4//Restore
#define NET_DVR_PLAYFAST		5//Play Faster
#define NET_DVR_PLAYSLOW		6//Play Slower
#define NET_DVR_PLAYNORMAL		7//Normal Speed
#define NET_DVR_PLAYSTARTAUDIO	9//Open Audio
#define NET_DVR_PLAYSTOPAUDIO	10//Close Audio
#define NET_DVR_PLAYSETPOS		12//Change playing progress

typedef struct 
{
	DWORD	dwSize;
	DWORD	dwPlayCmd;		/* Command of Play*/
	DWORD	dwCmdParam;		/* Parameter of Command*/
}NET_DVR_MATRIX_DEC_REMOTE_PLAY_CONTROL, *LPNET_DVR_MATRIX_DEC_REMOTE_PLAY_CONTROL;

typedef struct  
{
	DWORD dwSize;
	DWORD dwCurMediaFileLen;		/* Current file length  */       
	DWORD dwCurMediaFilePosition;	/* Current file position */        
	DWORD dwCurMediaFileDuration;	/* Current file duration */        
	DWORD dwCurPlayTime;			/* Current playback time  */        
	DWORD dwCurMediaFIleFrames;		/* Current playback frame number  */        
	DWORD dwCurDataType;			/* Current strean type, 19-file header, 20- stream data, 21-end */        
	BYTE res[72];	
}NET_DVR_MATRIX_DEC_REMOTE_PLAY_STATUS, *LPNET_DVR_MATRIX_DEC_REMOTE_PLAY_STATUS;
/************************************Decoder(end)***************************************/

typedef struct 
{	/* 12 bytes */
	DWORD	dwSize;
	char	sUserName[32];
	char 	sPassWord[32];
	char 	sFromName[32];			/* Sender */
	char 	sFromAddr[48];			/* Sender address */
	char 	sToName1[32];			/* Receiver1 */
	char 	sToName2[32];			/* Receiver2 */
	char 	sToAddr1[48];			/* Receiver address1 */
	char 	sToAddr2[48];			/* Receiver address2 */
	char	sEmailServer[32];		/* Email server address */
	BYTE	byServerType;			/* Email server type: 0-SMTP, 1-POP, 2-IMTP*/
	BYTE	byUseAuthen;			/* Email server authentication method: 1-enable, 0-disable */
	BYTE	byAttachment;			/* enable attachment */
	BYTE	byMailinterval;			/* mail interval 0-2s, 1-3s, 2-4s. 3-5s*/
} NET_DVR_EMAILCFG, *LPNET_DVR_EMAILCFG;

typedef struct 
{
	DWORD dwSize;
	NET_DVR_COMPRESSION_INFO_EX  struLowCompression;	// Time Record
	NET_DVR_COMPRESSION_INFO_EX  struEventCompression;	//  Triggered by events
}NET_DVR_COMPRESSIONCFG_NEW, *LPNET_DVR_COMPRESSIONCFG_NEW;

//Posistion info of Speed Dome
typedef struct
{
    WORD wAction;//invalid 
    WORD wPanPos;//pan position
    WORD wTiltPos;//tilt position
    WORD wZoomPos;//zoom position
}NET_DVR_PTZPOS, *LPNET_DVR_PTZPOS;

//PTZ Scope Structure 
typedef struct
{
    WORD wPanPosMin;//min pan position
    WORD wPanPosMax;//max pan position
    WORD wTiltPosMin;//min tilt position
    WORD wTiltPosMax;//max tilt position
    WORD wZoomPosMin;//min zoom factor
    WORD wZoomPosMax;//max zoom factor
}NET_DVR_PTZSCOPE, *LPNET_DVR_PTZSCOPE;

//rtsp Configuration(Special for IP camera)
typedef struct
{
    DWORD dwSize;         //Length
    WORD  wPort;          //rtsp Port
    BYTE  byReserve[54];  //Reserved
}NET_DVR_RTSPCFG, *LPNET_DVR_RTSPCFG;


/********************************Interface Parameters Structure(begin)*********************************/

//NET_DVR_Login()
typedef struct
{
	BYTE sSerialNumber[SERIALNO_LEN];   //SN
	BYTE byAlarmInPortNum;		        //DVR Alarm input
	BYTE byAlarmOutPortNum;		        //DVR Alarm Output
	BYTE byDiskNum;				        //DVR Number of Hard Disk
	BYTE byDVRType;				        //DVR Type, 1:DVR 2:ATM DVR 3:DVS ......
	BYTE byChanNum;				        //DVR Number of Channel
	BYTE byStartChan;			        //The first Channel No. E.g. DVS-1,DVR-1
}NET_DVR_DEVICEINFO, *LPNET_DVR_DEVICEINFO;

//NET_DVR_Login_V30()
typedef struct
{
    BYTE sSerialNumber[SERIALNO_LEN];   //SN
    BYTE byAlarmInPortNum;		        //Number of Alarm input
    BYTE byAlarmOutPortNum;		        //Number of Alarm Output
    BYTE byDiskNum;						//Number of Hard Disk
    BYTE byDVRType;						//DVR Type, 1:DVR 2:ATM DVR 3:DVS ......
    BYTE byChanNum;						//Number of Analog Channel
    BYTE byStartChan;			        //The first Channel No. E.g. DVS-1,DVR-1
    BYTE byAudioChanNum;                //Number of Audio Channel
    BYTE byIPChanNum;					//Maximum number of IP Channel  
	BYTE byRes1[24];					//Reserved
}NET_DVR_DEVICEINFO_V30, *LPNET_DVR_DEVICEINFO_V30;

//sdk Network environment, for update
typedef enum _SDK_NET_ENV
{
    LOCAL_AREA_NETWORK = 0,
        WIDE_AREA_NETWORK
}SDK_NETWORK_ENVIRONMENT;

//Display Mode
typedef enum
{
	NORMALMODE = 0,
	OVERLAYMODE
}DISPLAY_MODE;

//Send Mode
typedef enum
{
	PTOPTCPMODE = 0,
	PTOPUDPMODE,
	MULTIMODE,
	RTPMODE,
	RESERVEDMODE
}SEND_MODE;

//Grub Mode
typedef enum 
{
	BMP_MODE = 0,		//BMP Mode
	JPEG_MODE = 1		//JPEG Mode 
}CAPTURE_MODE;

//Real time Audio mode
typedef enum
{
	MONOPOLIZE_MODE = 1,//exclusive mode
	SHARE_MODE = 2		//shared mode
}REALSOUND_MODE;

//Preview via software decoding
typedef struct
{
	LONG lChannel;//channel no.
	LONG lLinkMode;//If 31st bit is 0, it means connect main stream, is 1 means sub stream. Bit 0~bit 30 are used for link mode: 0: TCP mode, 1: UDP mode, 2: Multi-play mode, 3: RTP mode, 4: audio, video separated mode; 3-RTP mode
	HWND hPlayWnd;// the play window's handle; set NULL to disable preview
	char* sMultiCastIP; //Multicast group
}NET_DVR_CLIENTINFO, *LPNET_DVR_CLIENTINFO;

//SDK infromation(9000 added)
typedef struct 
{
    DWORD dwTotalLoginNum;		//current login user operation number
    DWORD dwTotalRealPlayNum;	//current realplay operation number
    DWORD dwTotalPlayBackNum;	//current playback or download operation number
    DWORD dwTotalAlarmChanNum;	//current alarm channel operation number
    DWORD dwTotalFormatNum;		//current HDD format operation number
    DWORD dwTotalFileSearchNum;	//current files search operation number
    DWORD dwTotalLogSearchNum;	//current logs search operation number
    DWORD dwTotalSerialNum;	    //current transparent series port operation number
    DWORD dwTotalUpgradeNum;	//current upgrading operation number
    DWORD dwTotalVoiceComNum;	//current network voice communication operation number
    DWORD dwTotalBroadCastNum;	//current network broadcast voice communication operation number
    DWORD dwRes[10];
}NET_DVR_SDKSTATE, *LPNET_DVR_SDKSTATE;

//SDK Ability Information (9000 added)
typedef struct 
{
    DWORD dwMaxLoginNum;		//maximum login user operation number MAX_LOGIN_USERS
    DWORD dwMaxRealPlayNum;		//maximum realplay operation number WATCH_NUM
    DWORD dwMaxPlayBackNum;		//maximum playback or download operation number WATCH_NUM
    DWORD dwMaxAlarmChanNum;	//maximum alarm channel operation number ALARM_NUM
    DWORD dwMaxFormatNum;		//maximum HDD format operation number SERVER_NUM
    DWORD dwMaxFileSearchNum;	//maximum files search operation number SERVER_NUM
    DWORD dwMaxLogSearchNum;	//maximum logs search operation number SERVER_NUM
    DWORD dwMaxSerialNum;	    //maximum transparent series port operation number SERVER_NUM
    DWORD dwMaxUpgradeNum;	    //maximum current upgrading operation number SERVER_NUM
    DWORD dwMaxVoiceComNum;		//maximum network voice communication operation number SERVER_NUM
    DWORD dwMaxBroadCastNum;	//maximum network broadcast voice communication operation number MAX_CASTNUM
    DWORD dwRes[10];
}NET_DVR_SDKABL, *LPNET_DVR_SDKABL;

//Alarm Device Infor
typedef struct
{   
    BYTE byUserIDValid;                 /* Whether userid is valid, 0-invalid 1-valid. */
    BYTE bySerialValid;                 /* Whether serial number is valid, 0-invalid 1-valid.  */
    BYTE byVersionValid;                /* Whether version number is valid, 0-invalid 1-valid. */
    BYTE byDeviceNameValid;             /* Whether device name is valid, 0-invalid 1-valid. */
    BYTE byMacAddrValid;                /* Whether MAC address is valid, 0-invalid 1-valid. */    
    BYTE byLinkPortValid;               /* Whether login port number is valid, 0-invalid 1-valid. */
    BYTE byDeviceIPValid;               /* Whether device IP is valid, 0-invalid 1-valid./
    BYTE bySocketIPValid;               /* Whether socket IP is valid, 0-invalid 1-valid. */
    LONG lUserID;                       /* NET_DVR_Login()effective when establishing alarm upload channel*/
    BYTE sSerialNumber[SERIALNO_LEN];	/* Serial number. */
    DWORD dwDeviceVersion;			    /* Version number, 2 high byte means the major version, 2 low byte means the minor version*/
    char sDeviceName[NAME_LEN];		    /* Device name. */
    BYTE byMacAddr[MACADDR_LEN];		/* MAC address */    
    WORD wLinkPort;                     /* link port */
    char sDeviceIP[128];    			/* IP address */
    char sSocketIP[128];    			/* alarm push-mode socket IP address. */
    BYTE byIpProtocol;                  /* IP protocol: 0-IPV4; 1-IPV6. */
    BYTE byRes2[11];
}NET_DVR_ALARMER, *LPNET_DVR_ALARMER;

//Dispaly Area Parameter of Hardware Decoding(Sub Struct)
typedef struct
{
	long bToScreen;
	long bToVideoOut;
	long nLeft;
	long nTop;
	long nWidth;
	long nHeight;
	long nReserved;
}NET_DVR_DISPLAY_PARA, *LPNET_DVR_DISPLAY_PARA;

//Preview Parameter of Hardware Decoding
typedef struct
{
	LONG lChannel;// Channel No.
	LONG lLinkMode; //0- TCP; 1- UDP; 2- Multicast; 3- RTP; 4- PPPoE; 5- 128k; 6- 256k; 7- 384k; 8- 512k
	char* sMultiCastIP;
	NET_DVR_DISPLAY_PARA struDisplayPara;
}NET_DVR_CARDINFO, *LPNET_DVR_CARDINFO;

//Record Parameters
typedef struct 
{
	char sFileName[100];// File Name
	NET_DVR_TIME struStartTime;//Start time of the file
	NET_DVR_TIME struStopTime;//End time of the file
	DWORD dwFileSize;//File size
}NET_DVR_FIND_DATA, *LPNET_DVR_FIND_DATA;

//Record Parameters(9000)
typedef struct 
{
    char sFileName[100];//File Name
    NET_DVR_TIME struStartTime;//Start time of the file
    NET_DVR_TIME struStopTime;//End time of the file
    DWORD dwFileSize;//File size
    char sCardNum[32];
    BYTE byLocked;//9000 DVR supports this,1-file is locked,0-file is Normal
    BYTE byRes[3];
}NET_DVR_FINDDATA_V30, *LPNET_DVR_FINDDATA_V30;

//Record Parameters(with Card No.)
typedef struct 
{
	char sFileName[100];//File Name
	NET_DVR_TIME struStartTime;//Start time of the file
	NET_DVR_TIME struStopTime;//End time of the file
	DWORD dwFileSize;//File size
	char sCardNum[32];
}NET_DVR_FINDDATA_CARD, *LPNET_DVR_FINDDATA_CARD;


//Record Query Condition
typedef struct 
{
    LONG lChannel;//channel number
    DWORD dwFileType;/*file record mode oxff: all, 0: scheduled record, 1: Motion detection, 2: alarm record, 3: motion detection| alarm, 4: motion detection & alarm 5: command trigger, 6: manually record*/
    DWORD dwIsLocked;//whether file is locked, 0-normal; 1-locked;, 0xff-all
    DWORD dwUseCardNo;//whether card no. is used
    BYTE sCardNumber[32];//card no.
    NET_DVR_TIME struStartTime;//start time
    NET_DVR_TIME struStopTime;//end time
}NET_DVR_FILECOND, *LPNET_DVR_FILECOND;


// PTZ Image Zooming (Special for HIKVISION Speed dome)
typedef struct 
{
	int xTop;     //x coordinate of the origination point of the pane
	int yTop;     //y coordinate of the origination point of the pane
	int xBottom;  //x coordinate of the end point of the pane
	int yBottom;  //y coordinate of the end point of the pane
	int bCounter; //reserve
}NET_DVR_POINT_FRAME, *LPNET_DVR_POINT_FRAME;

//audio encode type
typedef struct 
{
	BYTE  byAudioEncType;   //AudioTalk Code Type 0-G722; 1-G711
	BYTE  byres[7];   //reserve
}NET_DVR_COMPRESSION_AUDIO, *LPNET_DVR_COMPRESSION_AUDIO;
/********************************Interface Parameter Struct(end)*********************************/


/********************************SDK API Definition*********************************/
NET_DVR_API BOOL __stdcall NET_DVR_Init();
NET_DVR_API BOOL __stdcall NET_DVR_Cleanup();
NET_DVR_API BOOL __stdcall NET_DVR_SetDVRMessage(UINT nMessage,HWND hWnd);
//NET_DVR_SetDVRMessageextended
NET_DVR_API BOOL __stdcall NET_DVR_SetExceptionCallBack_V30(UINT nMessage, HWND hWnd, void (CALLBACK* fExceptionCallBack)(DWORD dwType, LONG lUserID, LONG lHandle, void *pUser), void *pUser);

NET_DVR_API BOOL __stdcall NET_DVR_SetDVRMessCallBack(BOOL (CALLBACK *fMessCallBack)(LONG lCommand,char *sDVRIP,char *pBuf,DWORD dwBufLen));
NET_DVR_API BOOL __stdcall NET_DVR_SetDVRMessCallBack_EX(BOOL (CALLBACK *fMessCallBack_EX)(LONG lCommand,LONG lUserID,char *pBuf,DWORD dwBufLen));
NET_DVR_API BOOL __stdcall NET_DVR_SetDVRMessCallBack_NEW(BOOL (CALLBACK *fMessCallBack_NEW)(LONG lCommand,char *sDVRIP,char *pBuf,DWORD dwBufLen, WORD dwLinkDVRPort));
NET_DVR_API BOOL __stdcall NET_DVR_SetDVRMessageCallBack(BOOL (CALLBACK *fMessageCallBack)(LONG lCommand,char *sDVRIP,char *pBuf,DWORD dwBufLen, DWORD dwUser), DWORD dwUser);
typedef void (CALLBACK *MSGCallBack)(LONG lCommand, NET_DVR_ALARMER *pAlarmer, char *pAlarmInfo, DWORD dwBufLen, void* pUser);
NET_DVR_API BOOL __stdcall NET_DVR_SetDVRMessageCallBack_V30(MSGCallBack fMessageCallBack, void* pUser);

NET_DVR_API BOOL __stdcall NET_DVR_SetConnectTime(DWORD dwWaitTime = 5000, DWORD dwTryTimes = 3);
NET_DVR_API BOOL __stdcall NET_DVR_SetReconnect(DWORD dwInterval = 30000, BOOL bEnableRecon = TRUE);
NET_DVR_API DWORD __stdcall NET_DVR_GetSDKVersion();
NET_DVR_API DWORD __stdcall NET_DVR_GetSDKBuildVersion();
NET_DVR_API int __stdcall NET_DVR_IsSupport();
NET_DVR_API BOOL __stdcall NET_DVR_StartListen(char *sLocalIP,WORD wLocalPort);
NET_DVR_API BOOL __stdcall NET_DVR_StopListen();

NET_DVR_API LONG __stdcall NET_DVR_StartListen_V30(char *sLocalIP, WORD wLocalPort, MSGCallBack DataCallback = NULL, void* pUserData = NULL);
NET_DVR_API BOOL __stdcall NET_DVR_StopListen_V30(LONG lListenHandle);
NET_DVR_API LONG __stdcall NET_DVR_Login(char *sDVRIP,WORD wDVRPort,char *sUserName,char *sPassword,LPNET_DVR_DEVICEINFO lpDeviceInfo);
NET_DVR_API LONG __stdcall NET_DVR_Login_V30(char *sDVRIP, WORD wDVRPort, char *sUserName, char *sPassword, LPNET_DVR_DEVICEINFO_V30 lpDeviceInfo);
NET_DVR_API BOOL __stdcall NET_DVR_Logout(LONG lUserID);
NET_DVR_API BOOL __stdcall NET_DVR_Logout_V30(LONG lUserID);
NET_DVR_API DWORD __stdcall NET_DVR_GetLastError();
NET_DVR_API char* __stdcall NET_DVR_GetErrorMsg(LONG *pErrorNo = NULL);
NET_DVR_API BOOL __stdcall NET_DVR_SetShowMode(DWORD dwShowType,COLORREF colorKey);
NET_DVR_API BOOL __stdcall NET_DVR_GetDVRIPByResolveSvr(char *sServerIP, WORD wServerPort, BYTE *sDVRName,WORD wDVRNameLen,BYTE *sDVRSerialNumber,WORD wDVRSerialLen,char* sGetIP);
NET_DVR_API BOOL  __stdcall NET_DVR_GetDVRIPByResolveSvr_EX(char *sServerIP, WORD wServerPort, unsigned char *sDVRName, WORD wDVRNameLen, BYTE *sDVRSerialNumber, WORD wDVRSerialLen, char* sGetIP, DWORD *dwPort);

//Preview
NET_DVR_API LONG __stdcall NET_DVR_RealPlay(LONG lUserID,LPNET_DVR_CLIENTINFO lpClientInfo);
NET_DVR_API LONG __stdcall NET_DVR_RealPlay_V30(LONG lUserID, LPNET_DVR_CLIENTINFO lpClientInfo, void(CALLBACK *fRealDataCallBack_V30) (LONG lRealHandle, DWORD dwDataType, BYTE *pBuffer, DWORD dwBufSize, void* pUser) = NULL, void* pUser = NULL, BOOL bBlocked = FALSE);
NET_DVR_API BOOL __stdcall NET_DVR_StopRealPlay(LONG lRealHandle);
NET_DVR_API BOOL __stdcall NET_DVR_RigisterDrawFun(LONG lRealHandle,void (CALLBACK* fDrawFun)(LONG lRealHandle,HDC hDc,DWORD dwUser),DWORD dwUser);
NET_DVR_API BOOL __stdcall NET_DVR_SetPlayerBufNumber(LONG lRealHandle,DWORD dwBufNum);
NET_DVR_API BOOL __stdcall NET_DVR_ThrowBFrame(LONG lRealHandle,DWORD dwNum);
NET_DVR_API BOOL __stdcall NET_DVR_SetAudioMode(DWORD dwMode);
NET_DVR_API BOOL __stdcall NET_DVR_OpenSound(LONG lRealHandle);
NET_DVR_API BOOL __stdcall NET_DVR_CloseSound();
NET_DVR_API BOOL __stdcall NET_DVR_OpenSoundShare(LONG lRealHandle);
NET_DVR_API BOOL __stdcall NET_DVR_CloseSoundShare(LONG lRealHandle);
NET_DVR_API BOOL __stdcall NET_DVR_Volume(LONG lRealHandle,WORD wVolume);
NET_DVR_API BOOL __stdcall NET_DVR_SaveRealData(LONG lRealHandle,char *sFileName);
NET_DVR_API BOOL __stdcall NET_DVR_StopSaveRealData(LONG lRealHandle);
NET_DVR_API BOOL __stdcall NET_DVR_SetRealDataCallBack(LONG lRealHandle,void(CALLBACK *fRealDataCallBack) (LONG lRealHandle, DWORD dwDataType, BYTE *pBuffer,DWORD dwBufSize,DWORD dwUser),DWORD dwUser);
NET_DVR_API BOOL __stdcall NET_DVR_SetStandardDataCallBack(LONG lRealHandle,void(CALLBACK *fStdDataCallBack) (LONG lRealHandle, DWORD dwDataType, BYTE *pBuffer,DWORD dwBufSize,DWORD dwUser),DWORD dwUser);
NET_DVR_API BOOL __stdcall NET_DVR_CapturePicture(LONG lRealHandle,char *sPicFileName);//bmp

//Create I Frame Manually
NET_DVR_API BOOL __stdcall NET_DVR_MakeKeyFrame(LONG lUserID, LONG lChannel);//Main Stream
NET_DVR_API BOOL __stdcall NET_DVR_MakeKeyFrameSub(LONG lUserID, LONG lChannel);//Sub Stream

//PTZ
NET_DVR_API BOOL __stdcall NET_DVR_PTZControl(LONG lRealHandle,DWORD dwPTZCommand,DWORD dwStop);
NET_DVR_API BOOL __stdcall NET_DVR_PTZControl_Other(LONG lUserID,LONG lChannel,DWORD dwPTZCommand,DWORD dwStop);
NET_DVR_API BOOL __stdcall NET_DVR_TransPTZ(LONG lRealHandle,char *pPTZCodeBuf,DWORD dwBufSize);
NET_DVR_API BOOL __stdcall NET_DVR_TransPTZ_Other(LONG lUserID,LONG lChannel,char *pPTZCodeBuf,DWORD dwBufSize);
NET_DVR_API BOOL __stdcall NET_DVR_PTZPreset(LONG lRealHandle,DWORD dwPTZPresetCmd,DWORD dwPresetIndex);
NET_DVR_API BOOL __stdcall NET_DVR_PTZPreset_Other(LONG lUserID,LONG lChannel,DWORD dwPTZPresetCmd,DWORD dwPresetIndex);
NET_DVR_API BOOL __stdcall NET_DVR_TransPTZ_EX(LONG lRealHandle,char *pPTZCodeBuf,DWORD dwBufSize);
NET_DVR_API BOOL __stdcall NET_DVR_PTZControl_EX(LONG lRealHandle,DWORD dwPTZCommand,DWORD dwStop);
NET_DVR_API BOOL __stdcall NET_DVR_PTZPreset_EX(LONG lRealHandle,DWORD dwPTZPresetCmd,DWORD dwPresetIndex);
NET_DVR_API BOOL __stdcall NET_DVR_PTZCruise(LONG lRealHandle,DWORD dwPTZCruiseCmd,BYTE byCruiseRoute, BYTE byCruisePoint, WORD wInput);
NET_DVR_API BOOL __stdcall NET_DVR_PTZCruise_Other(LONG lUserID,LONG lChannel,DWORD dwPTZCruiseCmd,BYTE byCruiseRoute, BYTE byCruisePoint, WORD wInput);
NET_DVR_API BOOL __stdcall NET_DVR_PTZCruise_EX(LONG lRealHandle,DWORD dwPTZCruiseCmd,BYTE byCruiseRoute, BYTE byCruisePoint, WORD wInput);
NET_DVR_API BOOL __stdcall NET_DVR_PTZTrack(LONG lRealHandle, DWORD dwPTZTrackCmd);
NET_DVR_API BOOL __stdcall NET_DVR_PTZTrack_Other(LONG lUserID, LONG lChannel, DWORD dwPTZTrackCmd);
NET_DVR_API BOOL __stdcall NET_DVR_PTZTrack_EX(LONG lRealHandle, DWORD dwPTZTrackCmd);
NET_DVR_API BOOL __stdcall NET_DVR_PTZControlWithSpeed(LONG lRealHandle, DWORD dwPTZCommand, DWORD dwStop, DWORD dwSpeed);
NET_DVR_API BOOL __stdcall NET_DVR_PTZControlWithSpeed_Other(LONG lUserID, LONG lChannel, DWORD dwPTZCommand, DWORD dwStop, DWORD dwSpeed);
NET_DVR_API BOOL __stdcall NET_DVR_PTZControlWithSpeed_EX(LONG lRealHandle, DWORD dwPTZCommand, DWORD dwStop, DWORD dwSpeed);
NET_DVR_API BOOL __stdcall NET_DVR_GetPTZCruise(LONG lUserID,LONG lChannel,LONG lCruiseRoute, LPNET_DVR_CRUISE_RET lpCruiseRet);
NET_DVR_API BOOL __stdcall NET_DVR_PTZMltTrack(LONG lRealHandle,DWORD dwPTZTrackCmd, DWORD dwTrackIndex);
NET_DVR_API BOOL __stdcall NET_DVR_PTZMltTrack_Other(LONG lUserID,LONG lChannel,DWORD dwPTZTrackCmd, DWORD dwTrackIndex);
NET_DVR_API BOOL __stdcall NET_DVR_PTZMltTrack_EX(LONG lRealHandle,DWORD dwPTZTrackCmd, DWORD dwTrackIndex);

//Record Query & Playback
NET_DVR_API LONG __stdcall NET_DVR_FindFile(LONG lUserID,LONG lChannel,DWORD dwFileType, LPNET_DVR_TIME lpStartTime, LPNET_DVR_TIME lpStopTime);
NET_DVR_API LONG __stdcall NET_DVR_FindNextFile(LONG lFindHandle,LPNET_DVR_FIND_DATA lpFindData);
NET_DVR_API BOOL __stdcall NET_DVR_FindClose(LONG lFindHandle);
NET_DVR_API LONG __stdcall NET_DVR_FindNextFile_V30(LONG lFindHandle, LPNET_DVR_FINDDATA_V30 lpFindData);
NET_DVR_API LONG __stdcall NET_DVR_FindFile_V30(LONG lUserID, LPNET_DVR_FILECOND pFindCond);
NET_DVR_API BOOL __stdcall NET_DVR_FindClose_V30(LONG lFindHandle);
//2007-04-16 added to query files with Card No.
NET_DVR_API LONG __stdcall NET_DVR_FindNextFile_Card(LONG lFindHandle, LPNET_DVR_FINDDATA_CARD lpFindData);
NET_DVR_API LONG __stdcall NET_DVR_FindFile_Card(LONG lUserID, LONG lChannel, DWORD dwFileType, LPNET_DVR_TIME lpStartTime, LPNET_DVR_TIME lpStopTime);
NET_DVR_API BOOL __stdcall NET_DVR_LockFileByName(LONG lUserID, char *sLockFileName);
NET_DVR_API BOOL __stdcall NET_DVR_UnlockFileByName(LONG lUserID, char *sUnlockFileName);
NET_DVR_API LONG __stdcall NET_DVR_PlayBackByName(LONG lUserID,char *sPlayBackFileName, HWND hWnd);
NET_DVR_API LONG __stdcall NET_DVR_PlayBackByTime(LONG lUserID,LONG lChannel, LPNET_DVR_TIME lpStartTime, LPNET_DVR_TIME lpStopTime, HWND hWnd);
NET_DVR_API BOOL __stdcall NET_DVR_PlayBackControl(LONG lPlayHandle,DWORD dwControlCode,DWORD dwInValue,DWORD *LPOutValue);
NET_DVR_API BOOL __stdcall NET_DVR_StopPlayBack(LONG lPlayHandle);
NET_DVR_API BOOL __stdcall NET_DVR_SetPlayDataCallBack(LONG lPlayHandle,void(CALLBACK *fPlayDataCallBack) (LONG lPlayHandle, DWORD dwDataType, BYTE *pBuffer,DWORD dwBufSize,DWORD dwUser),DWORD dwUser);
NET_DVR_API BOOL __stdcall NET_DVR_PlayBackSaveData(LONG lPlayHandle,char *sFileName);
NET_DVR_API BOOL __stdcall NET_DVR_StopPlayBackSave(LONG lPlayHandle);
NET_DVR_API BOOL __stdcall NET_DVR_GetPlayBackOsdTime(LONG lPlayHandle, LPNET_DVR_TIME lpOsdTime);
NET_DVR_API BOOL __stdcall NET_DVR_PlayBackCaptureFile(LONG lPlayHandle,char *sFileName);
NET_DVR_API LONG __stdcall NET_DVR_GetFileByName(LONG lUserID,char *sDVRFileName,char *sSavedFileName);
NET_DVR_API LONG __stdcall NET_DVR_GetFileByTime(LONG lUserID,LONG lChannel, LPNET_DVR_TIME lpStartTime, LPNET_DVR_TIME lpStopTime, char *sSavedFileName);
NET_DVR_API BOOL __stdcall NET_DVR_StopGetFile(LONG lFileHandle);
NET_DVR_API int __stdcall NET_DVR_GetDownloadPos(LONG lFileHandle);
NET_DVR_API int	__stdcall NET_DVR_GetPlayBackPos(LONG lPlayHandle);

//Upgrade
NET_DVR_API LONG __stdcall NET_DVR_Upgrade(LONG lUserID, char *sFileName);
NET_DVR_API int __stdcall NET_DVR_GetUpgradeState(LONG lUpgradeHandle);
NET_DVR_API int __stdcall NET_DVR_GetUpgradeProgress(LONG lUpgradeHandle);
NET_DVR_API BOOL __stdcall NET_DVR_CloseUpgradeHandle(LONG lUpgradeHandle);
NET_DVR_API BOOL __stdcall NET_DVR_SetNetworkEnvironment(DWORD dwEnvironmentLevel);
//Format HD Remotely
NET_DVR_API LONG __stdcall NET_DVR_FormatDisk(LONG lUserID,LONG lDiskNumber);
NET_DVR_API BOOL __stdcall NET_DVR_GetFormatProgress(LONG lFormatHandle, LONG *pCurrentFormatDisk,LONG *pCurrentDiskPos,LONG *pFormatStatic);
NET_DVR_API BOOL __stdcall NET_DVR_CloseFormatHandle(LONG lFormatHandle);
//Alarm
NET_DVR_API LONG __stdcall NET_DVR_SetupAlarmChan(LONG lUserID);
NET_DVR_API BOOL __stdcall NET_DVR_CloseAlarmChan(LONG lAlarmHandle);
NET_DVR_API LONG __stdcall NET_DVR_SetupAlarmChan_V30(LONG lUserID);
NET_DVR_API BOOL __stdcall NET_DVR_CloseAlarmChan_V30(LONG lAlarmHandle);
//Voice Talk
NET_DVR_API LONG __stdcall NET_DVR_StartVoiceCom(LONG lUserID, void(CALLBACK *fVoiceDataCallBack)(LONG lVoiceComHandle, char *pRecvDataBuffer, DWORD dwBufSize, BYTE byAudioFlag, DWORD dwUser), DWORD dwUser);
NET_DVR_API LONG __stdcall NET_DVR_StartVoiceCom_V30(LONG lUserID, DWORD dwVoiceChan, BOOL bNeedCBNoEncData, void(CALLBACK *fVoiceDataCallBack)(LONG lVoiceComHandle, char *pRecvDataBuffer, DWORD dwBufSize, BYTE byAudioFlag, void* pUser), void* pUser);
NET_DVR_API BOOL __stdcall NET_DVR_SetVoiceComClientVolume(LONG lVoiceComHandle, WORD wVolume);
NET_DVR_API BOOL __stdcall NET_DVR_StopVoiceCom(LONG lVoiceComHandle);
//Forward Voice
NET_DVR_API LONG __stdcall NET_DVR_StartVoiceCom_MR(LONG lUserID, void(CALLBACK *fVoiceDataCallBack)(LONG lVoiceComHandle, char *pRecvDataBuffer, DWORD dwBufSize, BYTE byAudioFlag, DWORD dwUser), DWORD dwUser);
NET_DVR_API LONG __stdcall NET_DVR_StartVoiceCom_MR_V30(LONG lUserID, DWORD dwVoiceChan, void(CALLBACK *fVoiceDataCallBack)(LONG lVoiceComHandle, char *pRecvDataBuffer, DWORD dwBufSize, BYTE byAudioFlag, void* pUser), void* pUser);
NET_DVR_API BOOL __stdcall NET_DVR_VoiceComSendData(LONG lVoiceComHandle, char *pSendBuf, DWORD dwBufSize);

//Voice Broadcast
NET_DVR_API BOOL __stdcall NET_DVR_ClientAudioStart();
NET_DVR_API BOOL __stdcall NET_DVR_ClientAudioStart_V30(void(CALLBACK *fVoiceDataCallBack)(char *pRecvDataBuffer, DWORD dwBufSize, void * pUser), void *pUser);
NET_DVR_API BOOL __stdcall NET_DVR_ClientAudioStop();
NET_DVR_API BOOL __stdcall NET_DVR_AddDVR(LONG lUserID);
NET_DVR_API LONG __stdcall NET_DVR_AddDVR_V30(LONG lUserID, DWORD dwVoiceChan);
NET_DVR_API BOOL __stdcall NET_DVR_DelDVR(LONG lUserID);
NET_DVR_API BOOL __stdcall NET_DVR_DelDVR_V30(LONG lVoiceHandle);
////////////////////////////////////////////////////////////
//Transparent Channel
NET_DVR_API LONG __stdcall NET_DVR_SerialStart(LONG lUserID,LONG lSerialPort,void(CALLBACK *fSerialDataCallBack)(LONG lSerialHandle,char *pRecvDataBuffer,DWORD dwBufSize,DWORD dwUser),DWORD dwUser);
//If RS485 is used as transparent channel, please specify the channel No. And different channels can have different RS485 parameters
NET_DVR_API BOOL __stdcall NET_DVR_SerialSend(LONG lSerialHandle, LONG lChannel, char *pSendBuf,DWORD dwBufSize);
NET_DVR_API BOOL __stdcall NET_DVR_SerialStop(LONG lSerialHandle);
NET_DVR_API BOOL __stdcall NET_DVR_SendTo232Port(LONG lUserID, char *pSendBuf, DWORD dwBufSize);
NET_DVR_API BOOL __stdcall NET_DVR_SendToSerialPort(LONG lUserID, DWORD dwSerialPort, DWORD dwSerialIndex, char *pSendBuf, DWORD dwBufSize);

//decoding nBitrate = 16000
NET_DVR_API void* __stdcall NET_DVR_InitG722Decoder(int nBitrate = 16000);
NET_DVR_API void __stdcall NET_DVR_ReleaseG722Decoder(void *pDecHandle);
NET_DVR_API BOOL __stdcall NET_DVR_DecodeG722Frame(void *pDecHandle, unsigned char* pInBuffer, unsigned char* pOutBuffer);
//encoding
NET_DVR_API void* __stdcall NET_DVR_InitG722Encoder();
NET_DVR_API BOOL __stdcall NET_DVR_EncodeG722Frame(void *pEncodeHandle,unsigned char* pInBuffer, unsigned char* pOutBuffer);
NET_DVR_API void __stdcall NET_DVR_ReleaseG722Encoder(void *pEncodeHandle);

//Control the local preview remotely
NET_DVR_API BOOL __stdcall NET_DVR_ClickKey(LONG lUserID, LONG lKeyIndex);
//Control the manual record remotely
NET_DVR_API BOOL __stdcall NET_DVR_StartDVRRecord(LONG lUserID,LONG lChannel,LONG lRecordType);
NET_DVR_API BOOL __stdcall NET_DVR_StopDVRRecord(LONG lUserID,LONG lChannel);
//Decoding Card
NET_DVR_API BOOL __stdcall NET_DVR_InitDevice_Card(long *pDeviceTotalChan);
NET_DVR_API BOOL __stdcall NET_DVR_ReleaseDevice_Card();
NET_DVR_API BOOL __stdcall NET_DVR_InitDDraw_Card(HWND hParent,COLORREF colorKey);
NET_DVR_API BOOL __stdcall NET_DVR_ReleaseDDraw_Card();
NET_DVR_API LONG __stdcall NET_DVR_RealPlay_Card(LONG lUserID,LPNET_DVR_CARDINFO lpCardInfo,long lChannelNum);
NET_DVR_API BOOL __stdcall NET_DVR_ResetPara_Card(LONG lRealHandle,LPNET_DVR_DISPLAY_PARA lpDisplayPara);
NET_DVR_API BOOL __stdcall NET_DVR_RefreshSurface_Card();
NET_DVR_API BOOL __stdcall NET_DVR_ClearSurface_Card();
NET_DVR_API BOOL __stdcall NET_DVR_RestoreSurface_Card();
NET_DVR_API BOOL __stdcall NET_DVR_OpenSound_Card(LONG lRealHandle);
NET_DVR_API BOOL __stdcall NET_DVR_CloseSound_Card(LONG lRealHandle);
NET_DVR_API BOOL __stdcall NET_DVR_SetVolume_Card(LONG lRealHandle,WORD wVolume);
NET_DVR_API BOOL __stdcall NET_DVR_AudioPreview_Card(LONG lRealHandle,BOOL bEnable);
NET_DVR_API LONG __stdcall NET_DVR_GetCardLastError_Card();
NET_DVR_API HANDLE __stdcall NET_DVR_GetChanHandle_Card(LONG lRealHandle);
NET_DVR_API BOOL __stdcall NET_DVR_CapturePicture_Card(LONG lRealHandle, char *sPicFileName);
//NET_DVR_GetSerialNum_Card is invalid, Call GetBoardDetail instead.
NET_DVR_API BOOL __stdcall NET_DVR_GetSerialNum_Card(long lChannelNum,DWORD *pDeviceSerialNo);
//Log
NET_DVR_API LONG __stdcall NET_DVR_FindDVRLog(LONG lUserID, LONG lSelectMode, DWORD dwMajorType,DWORD dwMinorType, LPNET_DVR_TIME lpStartTime, LPNET_DVR_TIME lpStopTime);
NET_DVR_API LONG __stdcall NET_DVR_FindNextLog(LONG lLogHandle, LPNET_DVR_LOG lpLogData);
NET_DVR_API BOOL __stdcall NET_DVR_FindLogClose(LONG lLogHandle);
NET_DVR_API LONG __stdcall NET_DVR_FindDVRLog_V30(LONG lUserID, LONG lSelectMode, DWORD dwMajorType,DWORD dwMinorType, LPNET_DVR_TIME lpStartTime, LPNET_DVR_TIME lpStopTime, BOOL bOnlySmart = FALSE);
NET_DVR_API LONG __stdcall NET_DVR_FindNextLog_V30(LONG lLogHandle, LPNET_DVR_LOG_V30 lpLogData);
NET_DVR_API BOOL __stdcall NET_DVR_FindLogClose_V30(LONG lLogHandle);

//ATM DVR
NET_DVR_API LONG __stdcall NET_DVR_FindFileByCard(LONG lUserID,LONG lChannel,DWORD dwFileType, int nFindType, BYTE *sCardNumber, LPNET_DVR_TIME lpStartTime, LPNET_DVR_TIME lpStopTime);


//Encoding
NET_DVR_API void* __stdcall NET_DVR_InitG722Encoder();
NET_DVR_API BOOL __stdcall NET_DVR_EncodeG722Frame(void *pEncodeHandle,unsigned char* pInBuffer, unsigned char* pOutBuffer);
NET_DVR_API void __stdcall NET_DVR_ReleaseG722Encoder(void *pEncodeHandle);
//2005-09-15
NET_DVR_API BOOL __stdcall NET_DVR_CaptureJPEGPicture(LONG lUserID, LONG lChannel, LPNET_DVR_JPEGPARA lpJpegPara, char *sPicFileName);
//Grab JPEG and save to RAM
NET_DVR_API BOOL __stdcall NET_DVR_CaptureJPEGPicture_NEW(LONG lUserID, LONG lChannel, LPNET_DVR_JPEGPARA lpJpegPara, char *sJpegPicBuffer, DWORD dwPicSize,  LPDWORD lpSizeReturned);


//2006-02-16
NET_DVR_API int __stdcall NET_DVR_GetRealPlayerIndex(LONG lRealHandle);
NET_DVR_API int __stdcall NET_DVR_GetPlayBackPlayerIndex(LONG lPlayHandle);

//2006-08-28 704-640 Scale
NET_DVR_API BOOL __stdcall NET_DVR_SetScaleCFG(LONG lUserID, DWORD dwScale);
NET_DVR_API BOOL __stdcall NET_DVR_GetScaleCFG(LONG lUserID, DWORD *lpOutScale);
NET_DVR_API BOOL __stdcall NET_DVR_SetScaleCFG_V30(LONG lUserID, LPNET_DVR_SCALECFG pScalecfg);
NET_DVR_API BOOL __stdcall NET_DVR_GetScaleCFG_V30(LONG lUserID, LPNET_DVR_SCALECFG pScalecfg);
//2006-08-28 Port of ATM 
NET_DVR_API BOOL __stdcall NET_DVR_SetATMPortCFG(LONG lUserID, WORD wATMPort);
NET_DVR_API BOOL __stdcall NET_DVR_GetATMPortCFG(LONG lUserID, WORD *LPOutATMPort);

//2006-11-10 Display on Multi displayer
NET_DVR_API BOOL __stdcall NET_DVR_InitDDrawDevice();
NET_DVR_API BOOL __stdcall NET_DVR_ReleaseDDrawDevice();
NET_DVR_API LONG __stdcall NET_DVR_GetDDrawDeviceTotalNums();
NET_DVR_API BOOL __stdcall NET_DVR_SetDDrawDevice(LONG lPlayPort, DWORD nDeviceNum);

NET_DVR_API BOOL __stdcall NET_DVR_PTZSelZoomIn(LONG lRealHandle, LPNET_DVR_POINT_FRAME pStruPointFrame);
NET_DVR_API BOOL __stdcall NET_DVR_PTZSelZoomIn_EX(LONG lUserID, LONG lChannel, LPNET_DVR_POINT_FRAME pStruPointFrame);



//Decoder DS-6001D/DS-6001F
NET_DVR_API BOOL __stdcall NET_DVR_StartDecode(LONG lUserID, LONG lChannel, LPNET_DVR_DECODERINFO lpDecoderinfo);
NET_DVR_API BOOL __stdcall NET_DVR_StopDecode(LONG lUserID, LONG lChannel);
NET_DVR_API BOOL __stdcall NET_DVR_GetDecoderState(LONG lUserID, LONG lChannel, LPNET_DVR_DECODERSTATE lpDecoderState);
//2005-08-01
NET_DVR_API BOOL __stdcall NET_DVR_SetDecInfo(LONG lUserID, LONG lChannel, LPNET_DVR_DECCFG lpDecoderinfo);
NET_DVR_API BOOL __stdcall NET_DVR_GetDecInfo(LONG lUserID, LONG lChannel, LPNET_DVR_DECCFG lpDecoderinfo);
NET_DVR_API BOOL __stdcall NET_DVR_SetDecTransPort(LONG lUserID, LPNET_DVR_PORTCFG lpTransPort);
NET_DVR_API BOOL __stdcall NET_DVR_GetDecTransPort(LONG lUserID, LPNET_DVR_PORTCFG lpTransPort);
NET_DVR_API BOOL __stdcall NET_DVR_DecPlayBackCtrl(LONG lUserID, LONG lChannel, DWORD dwControlCode, DWORD dwInValue,DWORD *LPOutValue, LPNET_DVR_PLAYREMOTEFILE lpRemoteFileInfo);
NET_DVR_API BOOL __stdcall NET_DVR_StartDecSpecialCon(LONG lUserID, LONG lChannel, LPNET_DVR_DECCHANINFO lpDecChanInfo);
NET_DVR_API BOOL __stdcall NET_DVR_StopDecSpecialCon(LONG lUserID, LONG lChannel, LPNET_DVR_DECCHANINFO lpDecChanInfo);
NET_DVR_API BOOL __stdcall NET_DVR_DecCtrlDec(LONG lUserID, LONG lChannel, DWORD dwControlCode);
NET_DVR_API BOOL __stdcall NET_DVR_DecCtrlScreen(LONG lUserID, LONG lChannel, DWORD dwControl);
NET_DVR_API BOOL __stdcall NET_DVR_GetDecCurLinkStatus(LONG lUserID, LONG lChannel, LPNET_DVR_DECSTATUS lpDecStatus);

//Multi-channel decoder
//2007-11-30 V211 support the API below //11
NET_DVR_API BOOL __stdcall NET_DVR_MatrixStartDynamic(LONG lUserID, DWORD dwDecChanNum, LPNET_DVR_MATRIX_DYNAMIC_DEC lpDynamicInfo);
NET_DVR_API BOOL __stdcall NET_DVR_MatrixStopDynamic(LONG lUserID, DWORD dwDecChanNum); 
NET_DVR_API BOOL __stdcall NET_DVR_MatrixGetDecChanInfo(LONG lUserID, DWORD dwDecChanNum, LPNET_DVR_MATRIX_DEC_CHAN_INFO lpInter);
NET_DVR_API BOOL __stdcall NET_DVR_MatrixSetLoopDecChanInfo(LONG lUserID, DWORD dwDecChanNum, LPNET_DVR_MATRIX_LOOP_DECINFO lpInter);
NET_DVR_API BOOL __stdcall NET_DVR_MatrixGetLoopDecChanInfo(LONG lUserID, DWORD dwDecChanNum, LPNET_DVR_MATRIX_LOOP_DECINFO lpInter);
NET_DVR_API BOOL __stdcall NET_DVR_MatrixSetLoopDecChanEnable(LONG lUserID, DWORD dwDecChanNum, DWORD dwEnable);
NET_DVR_API BOOL __stdcall NET_DVR_MatrixGetLoopDecChanEnable(LONG lUserID, DWORD dwDecChanNum, LPDWORD lpdwEnable);
NET_DVR_API BOOL __stdcall NET_DVR_MatrixGetLoopDecEnable(LONG lUserID, LPDWORD lpdwEnable);
NET_DVR_API BOOL __stdcall NET_DVR_MatrixSetDecChanEnable(LONG lUserID, DWORD dwDecChanNum, DWORD dwEnable);
NET_DVR_API BOOL __stdcall NET_DVR_MatrixGetDecChanEnable(LONG lUserID, DWORD dwDecChanNum, LPDWORD lpdwEnable);
NET_DVR_API BOOL __stdcall NET_DVR_MatrixGetDecChanStatus(LONG lUserID, DWORD dwDecChanNum, LPNET_DVR_MATRIX_DEC_CHAN_STATUS lpInter);
//2007-12-22  //18
NET_DVR_API BOOL __stdcall NET_DVR_MatrixSetTranInfo(LONG lUserID, LPNET_DVR_MATRIX_TRAN_CHAN_CONFIG lpTranInfo);
NET_DVR_API BOOL __stdcall NET_DVR_MatrixGetTranInfo(LONG lUserID, LPNET_DVR_MATRIX_TRAN_CHAN_CONFIG lpTranInfo);
NET_DVR_API BOOL __stdcall NET_DVR_MatrixSetRemotePlay(LONG lUserID, DWORD dwDecChanNum, LPNET_DVR_MATRIX_DEC_REMOTE_PLAY lpInter);
NET_DVR_API BOOL __stdcall NET_DVR_MatrixSetRemotePlayControl(LONG lUserID, DWORD dwDecChanNum, DWORD dwControlCode, DWORD dwInValue, DWORD *LPOutValue);
NET_DVR_API BOOL __stdcall NET_DVR_MatrixGetRemotePlayStatus(LONG lUserID, DWORD dwDecChanNum, LPNET_DVR_MATRIX_DEC_REMOTE_PLAY_STATUS lpOuter);
//end
NET_DVR_API BOOL __stdcall NET_DVR_RefreshPlay(LONG lPlayHandle);
//Restore default configuration
NET_DVR_API BOOL __stdcall NET_DVR_RestoreConfig(LONG lUserID);
//Save configuration
NET_DVR_API BOOL __stdcall NET_DVR_SaveConfig(LONG lUserID);
//Reboot
NET_DVR_API BOOL __stdcall NET_DVR_RebootDVR(LONG lUserID);
//Shutdown DVR
NET_DVR_API BOOL __stdcall NET_DVR_ShutDownDVR(LONG lUserID);



//config parameter begin
NET_DVR_API BOOL __stdcall NET_DVR_GetDVRConfig(LONG lUserID, DWORD dwCommand,LONG lChannel, LPVOID lpOutBuffer, DWORD dwOutBufferSize, LPDWORD lpBytesReturned);
NET_DVR_API BOOL __stdcall NET_DVR_SetDVRConfig(LONG lUserID, DWORD dwCommand,LONG lChannel, LPVOID lpInBuffer, DWORD dwInBufferSize);
NET_DVR_API BOOL __stdcall NET_DVR_GetDVRWorkState_V30(LONG lUserID, LPNET_DVR_WORKSTATE_V30 lpWorkState);
NET_DVR_API BOOL __stdcall NET_DVR_GetDVRWorkState(LONG lUserID, LPNET_DVR_WORKSTATE lpWorkState);
NET_DVR_API BOOL __stdcall NET_DVR_SetVideoEffect(LONG lUserID, LONG lChannel, DWORD dwBrightValue, DWORD dwContrastValue, DWORD dwSaturationValue, DWORD dwHueValue);
NET_DVR_API BOOL __stdcall NET_DVR_GetVideoEffect(LONG lUserID, LONG lChannel, DWORD *pBrightValue, DWORD *pContrastValue, DWORD *pSaturationValue, DWORD *pHueValue);
NET_DVR_API BOOL __stdcall NET_DVR_ClientGetframeformat(LONG lUserID, LPNET_DVR_FRAMEFORMAT lpFrameFormat);
NET_DVR_API BOOL __stdcall NET_DVR_ClientSetframeformat(LONG lUserID, LPNET_DVR_FRAMEFORMAT lpFrameFormat);
NET_DVR_API BOOL __stdcall NET_DVR_ClientGetframeformat_V30(LONG lUserID, LPNET_DVR_FRAMEFORMAT_V30 lpFrameFormat);
NET_DVR_API BOOL __stdcall NET_DVR_ClientSetframeformat_V30(LONG lUserID, LPNET_DVR_FRAMEFORMAT_V30 lpFrameFormat);
NET_DVR_API BOOL __stdcall NET_DVR_GetAlarmOut_V30(LONG lUserID, LPNET_DVR_ALARMOUTSTATUS_V30 lpAlarmOutState);
NET_DVR_API BOOL __stdcall NET_DVR_GetAlarmOut(LONG lUserID, LPNET_DVR_ALARMOUTSTATUS lpAlarmOutState);
NET_DVR_API BOOL __stdcall NET_DVR_SetAlarmOut(LONG lUserID, LONG lAlarmOutPort,LONG lAlarmOutStatic);

//Adjust video paramters
NET_DVR_API BOOL __stdcall NET_DVR_ClientSetVideoEffect(LONG lRealHandle,DWORD dwBrightValue,DWORD dwContrastValue, DWORD dwSaturationValue,DWORD dwHueValue);
NET_DVR_API BOOL __stdcall NET_DVR_ClientGetVideoEffect(LONG lRealHandle,DWORD *pBrightValue,DWORD *pContrastValue, DWORD *pSaturationValue,DWORD *pHueValue);

//Configuration File
NET_DVR_API BOOL __stdcall NET_DVR_GetConfigFile(LONG lUserID, char *sFileName);
NET_DVR_API BOOL __stdcall NET_DVR_SetConfigFile(LONG lUserID, char *sFileName);
NET_DVR_API BOOL __stdcall NET_DVR_GetConfigFile_V30(LONG lUserID, char *sOutBuffer, DWORD dwOutSize, DWORD *pReturnSize);

NET_DVR_API BOOL __stdcall NET_DVR_GetConfigFile_EX(LONG lUserID, char *sOutBuffer, DWORD dwOutSize);
NET_DVR_API BOOL __stdcall NET_DVR_SetConfigFile_EX(LONG lUserID, char *sInBuffer, DWORD dwInSize);

//write log file
NET_DVR_API BOOL __stdcall NET_DVR_SetLogToFile(BOOL bLogEnable = FALSE, char * strLogDir = NULL, BOOL bAutoDel = TRUE);
NET_DVR_API BOOL __stdcall NET_DVR_GetSDKState(LPNET_DVR_SDKSTATE pSDKState);
NET_DVR_API BOOL __stdcall NET_DVR_GetSDKAbility(LPNET_DVR_SDKABL pSDKAbl);
NET_DVR_API BOOL __stdcall NET_DVR_GetPTZProtocol(LONG lUserID, NET_DVR_PTZCFG *pPtzcfg);
//Lock Front Panel
NET_DVR_API BOOL __stdcall NET_DVR_LockPanel(LONG lUserID);
NET_DVR_API BOOL __stdcall NET_DVR_UnLockPanel(LONG lUserID);

NET_DVR_API BOOL __stdcall NET_DVR_SetRtspConfig(LONG lUserID, DWORD dwCommand, LPNET_DVR_RTSPCFG lpInBuffer, DWORD dwInBufferSize);
NET_DVR_API BOOL __stdcall NET_DVR_GetRtspConfig(LONG lUserID, DWORD dwCommand, LPNET_DVR_RTSPCFG lpOutBuffer, DWORD dwOutBufferSize);

#endif //
